/*******************************************************************************
* File Name: ADC2_PM.c
* Version 1.71
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "ADC2.h"


/***************************************
* Local data allocation
***************************************/

static ADC2_BACKUP_STRUCT  ADC2_backup =
{
    ADC2_DISABLED
};
    

/*******************************************************************************
* Function Name: ADC2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
*******************************************************************************/
void ADC2_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
*******************************************************************************/
void ADC2_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC2_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  ADC2_backup - modified.
*
*******************************************************************************/
void ADC2_Sleep(void)
{
    if((ADC2_PWRMGR_SAR_REG  & ADC2_ACT_PWR_SAR_EN) != 0u) 
    {
        ADC2_backup.enableState = ADC2_ENABLED;
        if((ADC2_SAR_CSR0_REG & ADC2_SAR_SOF_START_CONV) != 0u)
        {
            ADC2_backup.enableState |= ADC2_STARTED;
        }
        ADC2_Stop();
    }
    else
    {
        ADC2_backup.enableState = ADC2_DISABLED;
    }
    /*ADC2_SaveConfig();*/
}


/*******************************************************************************
* Function Name: ADC2_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  ADC2_backup - used. 
*
*******************************************************************************/
void ADC2_Wakeup(void)
{
    /*ADC2_RestoreConfig();*/
    if(ADC2_backup.enableState != ADC2_DISABLED)
    {
        ADC2_Enable();
        if((ADC2_backup.enableState & ADC2_STARTED) != 0u)
        {
            ADC2_StartConvert();
        }
    } 
}


/* [] END OF FILE */
