/*******************************************************************************
* File Name: ADC_PM.c
* Version 1.80
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ADC.h"


/***************************************
* Local data allocation
***************************************/

static ADC_BACKUP_STRUCT  ADC_backup =
{
    ADC_DISABLED
};
    

/*******************************************************************************
* Function Name: ADC_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
*******************************************************************************/
void ADC_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
*******************************************************************************/
void ADC_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  ADC_backup - modified.
*
*******************************************************************************/
void ADC_Sleep(void)
{
    if((ADC_PWRMGR_SAR_REG  & ADC_ACT_PWR_SAR_EN) != 0u) 
    {
        ADC_backup.enableState = ADC_ENABLED;
        if((ADC_SAR_CSR0_REG & ADC_SAR_SOF_START_CONV) != 0u)
        {
            ADC_backup.enableState |= ADC_STARTED;
        }
        ADC_Stop();
    }
    else
    {
        ADC_backup.enableState = ADC_DISABLED;
    }
    /*ADC_SaveConfig();*/
}


/*******************************************************************************
* Function Name: ADC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  ADC_backup - used. 
*
*******************************************************************************/
void ADC_Wakeup(void)
{
    /*ADC_RestoreConfig();*/
    if(ADC_backup.enableState != ADC_DISABLED)
    {
        ADC_Enable();
        if((ADC_backup.enableState & ADC_STARTED) != 0u)
        {
            ADC_StartConvert();
        }
    } 
}


/* [] END OF FILE */
