/*******************************************************************************
* File Name: ADC_Trig.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_ADC_Trig_H)
#define CY_CLOCK_ADC_Trig_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void ADC_Trig_Start(void) ;
void ADC_Trig_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void ADC_Trig_StopBlock(void) ;
#endif

void ADC_Trig_StandbyPower(uint8 state) ;
void ADC_Trig_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 ADC_Trig_GetDividerRegister(void) ;
void ADC_Trig_SetModeRegister(uint8 modeBitMask) ;
void ADC_Trig_ClearModeRegister(uint8 modeBitMask) ;
uint8 ADC_Trig_GetModeRegister(void) ;
void ADC_Trig_SetSourceRegister(uint8 clkSource) ;
uint8 ADC_Trig_GetSourceRegister(void) ;
#if defined(ADC_Trig__CFG3)
void ADC_Trig_SetPhaseRegister(uint8 clkPhase) ;
uint8 ADC_Trig_GetPhaseRegister(void) ;
#endif

#define ADC_Trig_Enable()                       ADC_Trig_Start()
#define ADC_Trig_Disable()                      ADC_Trig_Stop()
#define ADC_Trig_SetDivider(clkDivider)         ADC_Trig_SetDividerRegister(clkDivider, 1)
#define ADC_Trig_SetDividerValue(clkDivider)    ADC_Trig_SetDividerRegister((clkDivider) - 1, 1)
#define ADC_Trig_SetMode(clkMode)               ADC_Trig_SetModeRegister(clkMode)
#define ADC_Trig_SetSource(clkSource)           ADC_Trig_SetSourceRegister(clkSource)
#if defined(ADC_Trig__CFG3)
#define ADC_Trig_SetPhase(clkPhase)             ADC_Trig_SetPhaseRegister(clkPhase)
#define ADC_Trig_SetPhaseValue(clkPhase)        ADC_Trig_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define ADC_Trig_CLKEN              (* (reg8 *) ADC_Trig__PM_ACT_CFG)
#define ADC_Trig_CLKEN_PTR          ((reg8 *) ADC_Trig__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define ADC_Trig_CLKSTBY            (* (reg8 *) ADC_Trig__PM_STBY_CFG)
#define ADC_Trig_CLKSTBY_PTR        ((reg8 *) ADC_Trig__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define ADC_Trig_DIV_LSB            (* (reg8 *) ADC_Trig__CFG0)
#define ADC_Trig_DIV_LSB_PTR        ((reg8 *) ADC_Trig__CFG0)
#define ADC_Trig_DIV_PTR            ((reg16 *) ADC_Trig__CFG0)

/* Clock MSB divider configuration register. */
#define ADC_Trig_DIV_MSB            (* (reg8 *) ADC_Trig__CFG1)
#define ADC_Trig_DIV_MSB_PTR        ((reg8 *) ADC_Trig__CFG1)

/* Mode and source configuration register */
#define ADC_Trig_MOD_SRC            (* (reg8 *) ADC_Trig__CFG2)
#define ADC_Trig_MOD_SRC_PTR        ((reg8 *) ADC_Trig__CFG2)

#if defined(ADC_Trig__CFG3)
/* Analog clock phase configuration register */
#define ADC_Trig_PHASE              (* (reg8 *) ADC_Trig__CFG3)
#define ADC_Trig_PHASE_PTR          ((reg8 *) ADC_Trig__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define ADC_Trig_CLKEN_MASK         ADC_Trig__PM_ACT_MSK
#define ADC_Trig_CLKSTBY_MASK       ADC_Trig__PM_STBY_MSK

/* CFG2 field masks */
#define ADC_Trig_SRC_SEL_MSK        ADC_Trig__CFG2_SRC_SEL_MASK
#define ADC_Trig_MODE_MASK          (~(ADC_Trig_SRC_SEL_MSK))

#if defined(ADC_Trig__CFG3)
/* CFG3 phase mask */
#define ADC_Trig_PHASE_MASK         ADC_Trig__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_ADC_Trig_H */


/* [] END OF FILE */
