/*******************************************************************************
* File Name: AdcClock.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_AdcClock_H)
#define CY_CLOCK_AdcClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void AdcClock_Start(void) ;
void AdcClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void AdcClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void AdcClock_StandbyPower(uint8 state) ;
void AdcClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 AdcClock_GetDividerRegister(void) ;
void AdcClock_SetModeRegister(uint8 modeBitMask) ;
void AdcClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 AdcClock_GetModeRegister(void) ;
void AdcClock_SetSourceRegister(uint8 clkSource) ;
uint8 AdcClock_GetSourceRegister(void) ;
#if defined(AdcClock__CFG3)
void AdcClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 AdcClock_GetPhaseRegister(void) ;
#endif /* defined(AdcClock__CFG3) */

#define AdcClock_Enable()                       AdcClock_Start()
#define AdcClock_Disable()                      AdcClock_Stop()
#define AdcClock_SetDivider(clkDivider)         AdcClock_SetDividerRegister(clkDivider, 1)
#define AdcClock_SetDividerValue(clkDivider)    AdcClock_SetDividerRegister((clkDivider) - 1, 1)
#define AdcClock_SetMode(clkMode)               AdcClock_SetModeRegister(clkMode)
#define AdcClock_SetSource(clkSource)           AdcClock_SetSourceRegister(clkSource)
#if defined(AdcClock__CFG3)
#define AdcClock_SetPhase(clkPhase)             AdcClock_SetPhaseRegister(clkPhase)
#define AdcClock_SetPhaseValue(clkPhase)        AdcClock_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(AdcClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define AdcClock_CLKEN              (* (reg8 *) AdcClock__PM_ACT_CFG)
#define AdcClock_CLKEN_PTR          ((reg8 *) AdcClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define AdcClock_CLKSTBY            (* (reg8 *) AdcClock__PM_STBY_CFG)
#define AdcClock_CLKSTBY_PTR        ((reg8 *) AdcClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define AdcClock_DIV_LSB            (* (reg8 *) AdcClock__CFG0)
#define AdcClock_DIV_LSB_PTR        ((reg8 *) AdcClock__CFG0)
#define AdcClock_DIV_PTR            ((reg16 *) AdcClock__CFG0)

/* Clock MSB divider configuration register. */
#define AdcClock_DIV_MSB            (* (reg8 *) AdcClock__CFG1)
#define AdcClock_DIV_MSB_PTR        ((reg8 *) AdcClock__CFG1)

/* Mode and source configuration register */
#define AdcClock_MOD_SRC            (* (reg8 *) AdcClock__CFG2)
#define AdcClock_MOD_SRC_PTR        ((reg8 *) AdcClock__CFG2)

#if defined(AdcClock__CFG3)
/* Analog clock phase configuration register */
#define AdcClock_PHASE              (* (reg8 *) AdcClock__CFG3)
#define AdcClock_PHASE_PTR          ((reg8 *) AdcClock__CFG3)
#endif /* defined(AdcClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define AdcClock_CLKEN_MASK         AdcClock__PM_ACT_MSK
#define AdcClock_CLKSTBY_MASK       AdcClock__PM_STBY_MSK

/* CFG2 field masks */
#define AdcClock_SRC_SEL_MSK        AdcClock__CFG2_SRC_SEL_MASK
#define AdcClock_MODE_MASK          (~(AdcClock_SRC_SEL_MSK))

#if defined(AdcClock__CFG3)
/* CFG3 phase mask */
#define AdcClock_PHASE_MASK         AdcClock__CFG3_PHASE_DLY_MASK
#endif /* defined(AdcClock__CFG3) */

#endif /* CY_CLOCK_AdcClock_H */


/* [] END OF FILE */
