/*******************************************************************************
* File Name: AdcISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <AdcISR.H>

#if !defined(AdcISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START AdcISR_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: AdcISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_Start(void)
{
    /* For all we know the interrupt is active. */
    AdcISR_Disable();

    /* Set the ISR to point to the AdcISR Interrupt. */
    AdcISR_SetVector(&AdcISR_Interrupt);

    /* Set the priority. */
    AdcISR_SetPriority((uint8)AdcISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    AdcISR_Enable();
}


/*******************************************************************************
* Function Name: AdcISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    AdcISR_Disable();

    /* Set the ISR to point to the AdcISR Interrupt. */
    AdcISR_SetVector(address);

    /* Set the priority. */
    AdcISR_SetPriority((uint8)AdcISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    AdcISR_Enable();
}


/*******************************************************************************
* Function Name: AdcISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_Stop(void)
{
    /* Disable this interrupt. */
    AdcISR_Disable();

    /* Set the ISR to point to the passive one. */
    AdcISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: AdcISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for AdcISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(AdcISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START AdcISR_Interrupt` */
extern
void ADC_ISR(void);	// ADC user call back process
	 ADC_ISR();	// ADC user call back process

	 AdcISR_ClearPending();

    /* `#END` */
}


/*******************************************************************************
* Function Name: AdcISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling AdcISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use AdcISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)AdcISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: AdcISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress AdcISR_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)AdcISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: AdcISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling AdcISR_Start
*   or AdcISR_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   AdcISR_Start or AdcISR_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_SetPriority(uint8 priority)
{
    *AdcISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: AdcISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 AdcISR_GetPriority(void)
{
    uint8 priority;


    priority = *AdcISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: AdcISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_Enable(void)
{
    /* Enable the general interrupt. */
    *AdcISR_INTC_SET_EN = AdcISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: AdcISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 AdcISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*AdcISR_INTC_SET_EN & (uint32)AdcISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: AdcISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_Disable(void)
{
    /* Disable the general interrupt. */
    *AdcISR_INTC_CLR_EN = AdcISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: AdcISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_SetPending(void)
{
    *AdcISR_INTC_SET_PD = AdcISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: AdcISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void AdcISR_ClearPending(void)
{
    *AdcISR_INTC_CLR_PD = AdcISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
