/*******************************************************************************
* File Name: AdcTrig.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_AdcTrig_H)
#define CY_CLOCK_AdcTrig_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void AdcTrig_Start(void) ;
void AdcTrig_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void AdcTrig_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void AdcTrig_StandbyPower(uint8 state) ;
void AdcTrig_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 AdcTrig_GetDividerRegister(void) ;
void AdcTrig_SetModeRegister(uint8 modeBitMask) ;
void AdcTrig_ClearModeRegister(uint8 modeBitMask) ;
uint8 AdcTrig_GetModeRegister(void) ;
void AdcTrig_SetSourceRegister(uint8 clkSource) ;
uint8 AdcTrig_GetSourceRegister(void) ;
#if defined(AdcTrig__CFG3)
void AdcTrig_SetPhaseRegister(uint8 clkPhase) ;
uint8 AdcTrig_GetPhaseRegister(void) ;
#endif /* defined(AdcTrig__CFG3) */

#define AdcTrig_Enable()                       AdcTrig_Start()
#define AdcTrig_Disable()                      AdcTrig_Stop()
#define AdcTrig_SetDivider(clkDivider)         AdcTrig_SetDividerRegister(clkDivider, 1)
#define AdcTrig_SetDividerValue(clkDivider)    AdcTrig_SetDividerRegister((clkDivider) - 1, 1)
#define AdcTrig_SetMode(clkMode)               AdcTrig_SetModeRegister(clkMode)
#define AdcTrig_SetSource(clkSource)           AdcTrig_SetSourceRegister(clkSource)
#if defined(AdcTrig__CFG3)
#define AdcTrig_SetPhase(clkPhase)             AdcTrig_SetPhaseRegister(clkPhase)
#define AdcTrig_SetPhaseValue(clkPhase)        AdcTrig_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(AdcTrig__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define AdcTrig_CLKEN              (* (reg8 *) AdcTrig__PM_ACT_CFG)
#define AdcTrig_CLKEN_PTR          ((reg8 *) AdcTrig__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define AdcTrig_CLKSTBY            (* (reg8 *) AdcTrig__PM_STBY_CFG)
#define AdcTrig_CLKSTBY_PTR        ((reg8 *) AdcTrig__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define AdcTrig_DIV_LSB            (* (reg8 *) AdcTrig__CFG0)
#define AdcTrig_DIV_LSB_PTR        ((reg8 *) AdcTrig__CFG0)
#define AdcTrig_DIV_PTR            ((reg16 *) AdcTrig__CFG0)

/* Clock MSB divider configuration register. */
#define AdcTrig_DIV_MSB            (* (reg8 *) AdcTrig__CFG1)
#define AdcTrig_DIV_MSB_PTR        ((reg8 *) AdcTrig__CFG1)

/* Mode and source configuration register */
#define AdcTrig_MOD_SRC            (* (reg8 *) AdcTrig__CFG2)
#define AdcTrig_MOD_SRC_PTR        ((reg8 *) AdcTrig__CFG2)

#if defined(AdcTrig__CFG3)
/* Analog clock phase configuration register */
#define AdcTrig_PHASE              (* (reg8 *) AdcTrig__CFG3)
#define AdcTrig_PHASE_PTR          ((reg8 *) AdcTrig__CFG3)
#endif /* defined(AdcTrig__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define AdcTrig_CLKEN_MASK         AdcTrig__PM_ACT_MSK
#define AdcTrig_CLKSTBY_MASK       AdcTrig__PM_STBY_MSK

/* CFG2 field masks */
#define AdcTrig_SRC_SEL_MSK        AdcTrig__CFG2_SRC_SEL_MASK
#define AdcTrig_MODE_MASK          (~(AdcTrig_SRC_SEL_MSK))

#if defined(AdcTrig__CFG3)
/* CFG3 phase mask */
#define AdcTrig_PHASE_MASK         AdcTrig__CFG3_PHASE_DLY_MASK
#endif /* defined(AdcTrig__CFG3) */

#endif /* CY_CLOCK_AdcTrig_H */


/* [] END OF FILE */
