/*******************************************************************************
* File Name: Amp2.c  
* Version 1.90
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Amp2.h"

#if (CY_PSOC5A)
    static Amp2_BACKUP_STRUCT  Amp2_backup;
#endif /* (CY_ PSOC5A) */

/* Constant array for gain settings */
const uint8 Amp2_GainArray[9] = { 
    (Amp2_RVAL_0K   | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=1  */
    (Amp2_RVAL_40K  | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=2  */
    (Amp2_RVAL_120K | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=4  */
    (Amp2_RVAL_280K | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=8  */
    (Amp2_RVAL_600K | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=16 */
    (Amp2_RVAL_460K | Amp2_R20_40B_40K | Amp2_BIAS_LOW), /* G=24, Sets Rin as 20k */
    (Amp2_RVAL_620K | Amp2_R20_40B_20K | Amp2_BIAS_LOW), /* G=32 */
    (Amp2_RVAL_470K | Amp2_R20_40B_20K | Amp2_BIAS_LOW), /* G=48, Sets Rin as 10k */
    (Amp2_RVAL_490K | Amp2_R20_40B_20K | Amp2_BIAS_LOW)  /* G=50, Sets Rin as 10k */
};

/* Constant array for gain compenstion settings */
const uint8 Amp2_GainComp[9] = { 
    ( Amp2_COMP_4P35PF  | ( Amp2_REDC_00 >> 2 )), /* G=1  */
    ( Amp2_COMP_4P35PF  | ( Amp2_REDC_01 >> 2 )), /* G=2  */
    ( Amp2_COMP_3P0PF   | ( Amp2_REDC_01 >> 2 )), /* G=4  */
    ( Amp2_COMP_3P0PF   | ( Amp2_REDC_01 >> 2 )), /* G=8  */
    ( Amp2_COMP_3P6PF   | ( Amp2_REDC_01 >> 2 )), /* G=16 */
    ( Amp2_COMP_3P6PF   | ( Amp2_REDC_11 >> 2 )), /* G=24 */
    ( Amp2_COMP_3P6PF   | ( Amp2_REDC_11 >> 2 )), /* G=32 */
    ( Amp2_COMP_3P6PF   | ( Amp2_REDC_00 >> 2 )), /* G=48 */
    ( Amp2_COMP_3P6PF   | ( Amp2_REDC_00 >> 2 ))  /* G=50 */
};

uint8 Amp2_initVar = 0u;

#if (CY_PSOC5A)
    uint8 Amp2_restoreVal = 0u;
#endif /* CY_PSOC5A */


/*******************************************************************************   
* Function Name: Amp2_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Amp2_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_Init(void) 
{
    /* Set PGA mode */
    Amp2_CR0_REG = Amp2_MODE_PGA;  
    
    /* Set non-inverting PGA mode and reference mode */
    Amp2_CR1_REG |= Amp2_PGA_NINV;  

    /* Set default gain and ref mode */
    Amp2_CR2_REG = Amp2_VREF_MODE;

    /* Set gain and compensation */
    Amp2_SetGain(Amp2_DEFAULT_GAIN);

    /* Set power */
    Amp2_SetPower(Amp2_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: Amp2_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_Enable(void) 
{
    /* If a boost clock is required */
    #if(Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV)
        Amp2_BST_REG |= Amp2_BST_REG_EN | CyScBoostClk__INDEX;
    #endif /* Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV */
   
    /* PSoC5A */
    #if (CY_PSOC5A)
        /* Enable Pump only if voltage is below threshold */
        if (Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV)
        {
            Amp2_SC_MISC_REG |= Amp2_PUMP_FORCE;
        }
        
    /* PSoC3, PSoC5LP*/
    #elif (CY_PSOC3 || CY_PSOC5LP)
        /* Enable charge Pump clock for SC block */
        Amp2_PUMP_CR1_REG |= Amp2_PUMP_CR1_SC_CLKSEL;
        /* Enable Pump only if voltage is below threshold */
        if (Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV)
        {
            Amp2_SC_MISC_REG |= Amp2_PUMP_FORCE;
        }
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    #if (CY_PSOC5A)
    if(Amp2_restoreVal == 1u)
    {
        Amp2_CR1_REG = Amp2_backup.scCr1Reg;
        Amp2_CR2_REG =Amp2_backup.scCr2Reg;
        Amp2_restoreVal = 0u;
    }
    #endif /* CY_PSOC5A */
     
    /* Enable power to the Amp in Active mode*/
    Amp2_PM_ACT_CFG_REG |= Amp2_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    Amp2_PM_STBY_CFG_REG |= Amp2_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: Amp2_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(Amp2_initVar == 0u)
    {
        Amp2_Init();
        Amp2_initVar = 1u;
    }

    Amp2_Enable();
}


/*******************************************************************************
* Function Name: Amp2_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_Stop(void) 
{
    /* Disable pumps only if only one SC block is in use */
    if (Amp2_PM_ACT_CFG_REG == Amp2_ACT_PWR_EN)
    {
       Amp2_SC_MISC_REG &= ~Amp2_PUMP_FORCE;
    }   
    /* Disble power to the Amp in Active mode template */
    Amp2_PM_ACT_CFG_REG &= ~Amp2_ACT_PWR_EN;

    /* Disble power to the Amp in Alternative Active mode template */
    Amp2_PM_STBY_CFG_REG &= ~Amp2_STBY_PWR_EN;

    /* If a boost clock is required */
    /* Disable SC Block boost clk control, if used (MinVdda < 2.7V) */
    #if(Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV)
        Amp2_BST_REG &= ~Amp2_BST_REG_EN;
    #endif /* Amp2_CYDEV_VDDA_MV < Amp2_MINIMUM_VDDA_THRESHOLD_MV */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        Amp2_backup.scCr1Reg = Amp2_CR1_REG;
        Amp2_backup.scCr2Reg = Amp2_CR2_REG;
        Amp2_CR1_REG = Amp2_SC_REG_CLR;
        Amp2_CR2_REG = Amp2_SC_REG_CLR;
        Amp2_restoreVal = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Amp2_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = Amp2_CR1_REG & ~Amp2_DRIVE_MASK;
    tmpCR |= (power & Amp2_DRIVE_MASK);
    Amp2_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: Amp2_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void Amp2_SetGain(uint8 gain) 
{
    /* Only set new gain if it is a valid gain */
    if( gain <= Amp2_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        Amp2_CR2_REG &= ~(Amp2_RVAL_MASK | Amp2_R20_40B_MASK | 
                                Amp2_REDC_MASK | Amp2_BIAS_MASK );

        /* Set gain value resistors, redc comp, and bias */
        Amp2_CR2_REG |= (Amp2_GainArray[gain] |
                                ( (Amp2_GainComp[gain] << 2 ) & Amp2_REDC_MASK));

        /* Clear sc_comp  */
        Amp2_CR1_REG &= ~Amp2_COMP_MASK;
        /* Set sc_comp  */
        Amp2_CR1_REG |= ( Amp2_GainComp[gain] | Amp2_COMP_MASK );
    }
}


/* [] END OF FILE */
