/*******************************************************************************
* File Name: Amp2.h  
* Version 1.90
*
* Description:
*  This file contains the function prototypes and constants used in
*  the PGA User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PGA_Amp2_H) 
#define CY_PGA_Amp2_H 

#include "cytypes.h"
#include "cyfitter.h"

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PGA_v1_90 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/***************************************
*   Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _Amp2_backupStruct
{
    uint8   enableState;
    uint8   scCr1Reg;
    uint8   scCr2Reg;
}   Amp2_BACKUP_STRUCT;


/***************************************
*        Function Prototypes 
***************************************/

void Amp2_Start(void)           ; 
void Amp2_Stop(void)            ; 
void Amp2_SetPower(uint8 power) ;
void Amp2_SetGain(uint8 gain)   ;
void Amp2_Sleep(void)           ; 
void Amp2_Wakeup(void)          ;
void Amp2_SaveConfig(void)      ; 
void Amp2_RestoreConfig(void)   ;
void Amp2_Init(void)            ;
void Amp2_Enable(void)          ;


/***************************************
*            API Constants
***************************************/

/* Power constants for SetPower function */
#define Amp2_MINPOWER            (0x00u)
#define Amp2_LOWPOWER            (0x01u)
#define Amp2_MEDPOWER            (0x02u)
#define Amp2_HIGHPOWER           (0x03u)

/* Constants for SetGain function */
#define Amp2_GAIN_01             (0x00u)
#define Amp2_GAIN_02             (0x01u)
#define Amp2_GAIN_04             (0x02u)
#define Amp2_GAIN_08             (0x03u)
#define Amp2_GAIN_16             (0x04u)
#define Amp2_GAIN_24             (0x05u)
#define Amp2_GAIN_32             (0x06u)
#define Amp2_GAIN_48             (0x07u)
#define Amp2_GAIN_50             (0x08u)
#define Amp2_GAIN_MAX            (0x08u)

/* Constant for VDDA Threshold */
#define Amp2_CYDEV_VDDA_MV       (CYDEV_VDDA_MV)

/* Constant for Minimum VDDA Threshold */
#define Amp2_MINIMUM_VDDA_THRESHOLD_MV   (2700u)


/***************************************
*       Initialization Values
***************************************/

#define Amp2_DEFAULT_GAIN        (0u)
#define Amp2_VREF_MODE           (0 ? 0x00u : Amp2_GNDVREF_E)
#define Amp2_DEFAULT_POWER       (3)


/***************************************
*              Registers
***************************************/

#define Amp2_CR0_REG                  (* (reg8 *) Amp2_SC__CR0 )
#define Amp2_CR0_PTR                  (  (reg8 *) Amp2_SC__CR0 )
#define Amp2_CR1_REG                  (* (reg8 *) Amp2_SC__CR1 )
#define Amp2_CR1_PTR                  (  (reg8 *) Amp2_SC__CR1 )
#define Amp2_CR2_REG                  (* (reg8 *) Amp2_SC__CR2 )
#define Amp2_CR2_PTR                  (  (reg8 *) Amp2_SC__CR2 )
  /* Power manager */
#define Amp2_PM_ACT_CFG_REG           (* (reg8 *) Amp2_SC__PM_ACT_CFG )
#define Amp2_PM_ACT_CFG_PTR           (  (reg8 *) Amp2_SC__PM_ACT_CFG )  
#define Amp2_PM_STBY_CFG_REG          (* (reg8 *) Amp2_SC__PM_STBY_CFG )
  /* Power manager */
#define Amp2_PM_STBY_CFG_PTR          (  (reg8 *) Amp2_SC__PM_STBY_CFG )  
#define Amp2_BST_REG                  (* (reg8 *) Amp2_SC__BST )
#define Amp2_BST_PTR                  (  (reg8 *) Amp2_SC__BST )
/* Pump clock selectin register */
#define Amp2_PUMP_CR1_REG             (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)
#define Amp2_PUMP_CR1_PTR             (  (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

/* Pump Register for SC block */
#define Amp2_SC_MISC_REG              (* (reg8 *) CYDEV_ANAIF_RT_SC_MISC)
#define Amp2_SC_MISC_PTR              (  (reg8 *) CYDEV_ANAIF_RT_SC_MISC)

/* PM_ACT_CFG (Active Power Mode CFG Register)mask */ 
#define Amp2_ACT_PWR_EN          Amp2_SC__PM_ACT_MSK 

/* PM_STBY_CFG (Alternate Active Power Mode CFG Register)mask */ 
#define Amp2_STBY_PWR_EN          Amp2_SC__PM_STBY_MSK 


/***************************************
*            Register Constants
***************************************/

/* SC_MISC constants */
#define Amp2_PUMP_FORCE          (0x20u)
#define Amp2_PUMP_AUTO           (0x10u)
#define Amp2_DIFF_PGA_1_3        (0x02u)
#define Amp2_DIFF_PGA_0_2        (0x01u)

/* ANIF.PUMP.CR1 Constants */
#define Amp2_PUMP_CR1_SC_CLKSEL  (0x80u)

/* CR0 SC/CT Control Register 0 definitions */
#define Amp2_MODE_PGA            (0x0Cu)

/* CR1 SC/CT Control Register 1 definitions */

/* Bit Field  SC_COMP_ENUM */
#define Amp2_COMP_MASK           (0x0Cu)
#define Amp2_COMP_3P0PF          (0x00u)
#define Amp2_COMP_3P6PF          (0x04u)
#define Amp2_COMP_4P35PF         (0x08u)
#define Amp2_COMP_5P1PF          (0x0Cu)

/* Bit Field  SC_DIV2_ENUM */
#define Amp2_DIV2_MASK           (0x10u)
#define Amp2_DIV2_DISABLE        (0x00u)
#define Amp2_DIV2_ENABLE         (0x10u)

/* Bit Field  SC_DRIVE_ENUM */
#define Amp2_DRIVE_MASK          (0x03u)
#define Amp2_DRIVE_280UA         (0x00u)
#define Amp2_DRIVE_420UA         (0x01u)
#define Amp2_DRIVE_530UA         (0x02u)
#define Amp2_DRIVE_650UA         (0x03u)

/* Bit Field  SC_PGA_MODE_ENUM */
#define Amp2_PGA_MODE_MASK       (0x20u)
#define Amp2_PGA_INV             (0x00u)
#define Amp2_PGA_NINV            (0x20u)

/* CR2 SC/CT Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM */
#define Amp2_BIAS_MASK           (0x01u)
#define Amp2_BIAS_NORMAL         (0x00u)
#define Amp2_BIAS_LOW            (0x01u)

/* Bit Field  SC_PGA_GNDVREF_ENUM  */
#define Amp2_GNDVREF_MASK        (0x80u)
#define Amp2_GNDVREF_DI          (0x00u)
#define Amp2_GNDVREF_E           (0x80u)

/* Bit Field  SC_R20_40B_ENUM */
#define Amp2_R20_40B_MASK        (0x02u)
#define Amp2_R20_40B_40K         (0x00u)
#define Amp2_R20_40B_20K         (0x02u)

/* Bit Field  SC_REDC_ENUM */
#define Amp2_REDC_MASK           (0x0Cu)
#define Amp2_REDC_00             (0x00u)
#define Amp2_REDC_01             (0x04u)
#define Amp2_REDC_10             (0x08u)
#define Amp2_REDC_11             (0x0Cu)

/* Bit Field  SC_RVAL_ENUM */
#define Amp2_RVAL_MASK           (0x70u)
#define Amp2_RVAL_0K             (0x00u)
#define Amp2_RVAL_40K            (0x10u)
#define Amp2_RVAL_120K           (0x20u)
#define Amp2_RVAL_280K           (0x30u)
#define Amp2_RVAL_600K           (0x40u)
#define Amp2_RVAL_460K           (0x60u)
#define Amp2_RVAL_620K           (0x50u)
#define Amp2_RVAL_470K           (0x60u)
#define Amp2_RVAL_490K           (0x70u)

/* Bit Field  PGA_GAIN_ENUM */
#define Amp2_PGA_GAIN_MASK       (0x72u)
#define Amp2_PGA_GAIN_01         (0x00u)
#define Amp2_PGA_GAIN_02         (0x10u)
#define Amp2_PGA_GAIN_04         (0x20u)
#define Amp2_PGA_GAIN_08         (0x30u)
#define Amp2_PGA_GAIN_16         (0x40u)
#define Amp2_PGA_GAIN_24         (0x50u)
#define Amp2_PGA_GAIN_25         (0x70u)
#define Amp2_PGA_GAIN_32         (0x52u)
#define Amp2_PGA_GAIN_48         (0x62u)
#define Amp2_PGA_GAIN_50         (0x72u)

#define  Amp2_SC_REG_CLR         (0x00u)

#define  Amp2_BST_REG_EN         (0x08u)

#endif /* CY_PGA_Amp2_H */


/* [] END OF FILE */
