/*******************************************************************************
* File Name: Amp2_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power manager source code to the API for PGA 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Amp2.h"

static Amp2_BACKUP_STRUCT  Amp2_backup;


/*******************************************************************************
* Function Name: Amp2_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user register configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: Amp2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restore the register configurations.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Amp2_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: Amp2_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Amp2_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void Amp2_Sleep(void) 
{
    /* Save PGA enable state */
    if(Amp2_ACT_PWR_EN == (Amp2_PM_ACT_CFG_REG & Amp2_ACT_PWR_EN))
    {
        /* Component is enabled */
        Amp2_backup.enableState = 1u;
    }
    else
    {
        /* Component is disabled */
        Amp2_backup.enableState = 0u;
    }

    /* Stop the configuration */
    Amp2_Stop();

    /* Save the configuration */
    Amp2_SaveConfig();
}


/*******************************************************************************
* Function Name: Amp2_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  void
*
* Global variables:
*  Amp2_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
* 
*******************************************************************************/
void Amp2_Wakeup(void) 
{
    /* Restore the configurations */
    Amp2_RestoreConfig();

     /* Enables the component operation */
    if(Amp2_backup.enableState == 1u)
    {
        Amp2_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
