/*******************************************************************************
* File Name: CkT.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "CkT.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CkT__PORT == 15 && (CkT__MASK & 0xC0))

/*******************************************************************************
* Function Name: CkT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void CkT_Write(uint8 value) 
{
    uint8 staticBits = CkT_DR & ~CkT_MASK;
    CkT_DR = staticBits | ((value << CkT_SHIFT) & CkT_MASK);
}


/*******************************************************************************
* Function Name: CkT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void CkT_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(CkT_0, mode);
}


/*******************************************************************************
* Function Name: CkT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CkT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CkT_Read(void) 
{
    return (CkT_PS & CkT_MASK) >> CkT_SHIFT;
}


/*******************************************************************************
* Function Name: CkT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CkT_ReadDataReg(void) 
{
    return (CkT_DR & CkT_MASK) >> CkT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CkT_INTSTAT) 

    /*******************************************************************************
    * Function Name: CkT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CkT_ClearInterrupt(void) 
    {
        return (CkT_INTSTAT & CkT_MASK) >> CkT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
