/*******************************************************************************
* File Name: ISR1.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <ISR1.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ISR1_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: ISR1_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR1_Start(void)
{
    /* For all we know the interrupt is active. */
    ISR1_Disable();

    /* Set the ISR to point to the ISR1 Interrupt. */
    ISR1_SetVector(ISR1_Interrupt);

    /* Set the priority. */
    ISR1_SetPriority(ISR1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR1_Enable();
}

/*******************************************************************************
* Function Name: ISR1_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR1_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ISR1_Disable();

    /* Set the ISR to point to the ISR1 Interrupt. */
    ISR1_SetVector(address);

    /* Set the priority. */
    ISR1_SetPriority(ISR1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR1_Enable();
}

/*******************************************************************************
* Function Name: ISR1_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR1_Stop(void) 
{
    /* Disable this interrupt. */
    ISR1_Disable();

    /* Set the ISR to point to the passive one. */
    ISR1_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: ISR1_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for ISR1.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(ISR1_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ISR1_Interrupt` */
	int i;	
	for( i=0; i<3; i++ )
	{	LED1_Write(0);
		CyDelay(10);
		LED1_Write(1);
		CyDelay(200);
	}
	CySoftwareReset();		// Description: Forces a software reset of the device.
    /* `#END` */
}

/*******************************************************************************
* Function Name: ISR1_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ISR1_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use ISR1_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + ISR1__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: ISR1_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress ISR1_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + ISR1__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: ISR1_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling ISR1_Start
*   or ISR1_StartEx will override any effect this method would have had. 
*	This method should only be called after ISR1_Start or 
*	ISR1_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_SetPriority(uint8 priority) 
{
    *ISR1_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: ISR1_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 ISR1_GetPriority(void) 
{
    uint8 priority;


    priority = *ISR1_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: ISR1_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_Enable(void) 
{
    /* Enable the general interrupt. */
    *ISR1_INTC_SET_EN = ISR1__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR1_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 ISR1_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*ISR1_INTC_SET_EN & ISR1__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: ISR1_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_Disable(void) 
{
    /* Disable the general interrupt. */
    *ISR1_INTC_CLR_EN = ISR1__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR1_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_SetPending(void) 
{
    *ISR1_INTC_SET_PD = ISR1__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR1_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR1_ClearPending(void) 
{
    *ISR1_INTC_CLR_PD = ISR1__INTC_MASK;
}
