/*******************************************************************************
* File Name: RE_BusClock1.h
* Version 1.60
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_RE_BusClock1_H)
#define CY_CLOCK_RE_BusClock1_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void RE_BusClock1_Start(void) ;
void RE_BusClock1_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void RE_BusClock1_StopBlock(void) ;
#endif

void RE_BusClock1_StandbyPower(uint8 state) ;
void RE_BusClock1_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 RE_BusClock1_GetDividerRegister(void) ;
void RE_BusClock1_SetModeRegister(uint8 modeBitMask) ;
void RE_BusClock1_ClearModeRegister(uint8 modeBitMask) ;
uint8 RE_BusClock1_GetModeRegister(void) ;
void RE_BusClock1_SetSourceRegister(uint8 clkSource) ;
uint8 RE_BusClock1_GetSourceRegister(void) ;
#if defined(RE_BusClock1__CFG3)
void RE_BusClock1_SetPhaseRegister(uint8 clkPhase) ;
uint8 RE_BusClock1_GetPhaseRegister(void) ;
#endif

#define RE_BusClock1_Enable()                       RE_BusClock1_Start()
#define RE_BusClock1_Disable()                      RE_BusClock1_Stop()
#define RE_BusClock1_SetDivider(clkDivider)         RE_BusClock1_SetDividerRegister(clkDivider, 1)
#define RE_BusClock1_SetDividerValue(clkDivider)    RE_BusClock1_SetDividerRegister((clkDivider) - 1, 1)
#define RE_BusClock1_SetMode(clkMode)               RE_BusClock1_SetModeRegister(clkMode)
#define RE_BusClock1_SetSource(clkSource)           RE_BusClock1_SetSourceRegister(clkSource)
#if defined(RE_BusClock1__CFG3)
#define RE_BusClock1_SetPhase(clkPhase)             RE_BusClock1_SetPhaseRegister(clkPhase)
#define RE_BusClock1_SetPhaseValue(clkPhase)        RE_BusClock1_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define RE_BusClock1_CLKEN              (* (reg8 *) RE_BusClock1__PM_ACT_CFG)
#define RE_BusClock1_CLKEN_PTR          ((reg8 *) RE_BusClock1__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define RE_BusClock1_CLKSTBY            (* (reg8 *) RE_BusClock1__PM_STBY_CFG)
#define RE_BusClock1_CLKSTBY_PTR        ((reg8 *) RE_BusClock1__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define RE_BusClock1_DIV_LSB            (* (reg8 *) RE_BusClock1__CFG0)
#define RE_BusClock1_DIV_LSB_PTR        ((reg8 *) RE_BusClock1__CFG0)
#define RE_BusClock1_DIV_PTR            ((reg16 *) RE_BusClock1__CFG0)

/* Clock MSB divider configuration register. */
#define RE_BusClock1_DIV_MSB            (* (reg8 *) RE_BusClock1__CFG1)
#define RE_BusClock1_DIV_MSB_PTR        ((reg8 *) RE_BusClock1__CFG1)

/* Mode and source configuration register */
#define RE_BusClock1_MOD_SRC            (* (reg8 *) RE_BusClock1__CFG2)
#define RE_BusClock1_MOD_SRC_PTR        ((reg8 *) RE_BusClock1__CFG2)

#if defined(RE_BusClock1__CFG3)
/* Analog clock phase configuration register */
#define RE_BusClock1_PHASE              (* (reg8 *) RE_BusClock1__CFG3)
#define RE_BusClock1_PHASE_PTR          ((reg8 *) RE_BusClock1__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define RE_BusClock1_CLKEN_MASK         RE_BusClock1__PM_ACT_MSK
#define RE_BusClock1_CLKSTBY_MASK       RE_BusClock1__PM_STBY_MSK

/* CFG2 field masks */
#define RE_BusClock1_SRC_SEL_MSK        RE_BusClock1__CFG2_SRC_SEL_MASK
#define RE_BusClock1_MODE_MASK          (~(RE_BusClock1_SRC_SEL_MSK))

#if defined(RE_BusClock1__CFG3)
/* CFG3 phase mask */
#define RE_BusClock1_PHASE_MASK         RE_BusClock1__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_RE_BusClock1_H */


/* [] END OF FILE */
