/*******************************************************************************
* File Name: RE_Counter1.c  
* Version 2.20
*
*  Description:
*     The Counter component consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "RE_Counter1.h"

uint8 RE_Counter1_initVar = 0u;


/*******************************************************************************
* Function Name: RE_Counter1_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void RE_Counter1_Init(void) 
{
        #if (!RE_Counter1_UsingFixedFunction && !RE_Counter1_ControlRegRemoved)
            uint8 ctrl;
        #endif /* (!RE_Counter1_UsingFixedFunction && !RE_Counter1_ControlRegRemoved) */
        
        #if(!RE_Counter1_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 RE_Counter1_interruptState;
        #endif /* (!RE_Counter1_UsingFixedFunction) */
        
        #if (RE_Counter1_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            RE_Counter1_CONTROL &= RE_Counter1_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (CY_PSOC5A)
                RE_Counter1_CONTROL2 &= ~RE_Counter1_CTRL_MODE_MASK;
            #endif /* (CY_PSOC5A) */
            #if (CY_PSOC3 || CY_PSOC5LP)
                RE_Counter1_CONTROL3 &= ~RE_Counter1_CTRL_MODE_MASK;                
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (RE_Counter1_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                RE_Counter1_CONTROL |= RE_Counter1_ONESHOT;
            #endif /* (RE_Counter1_RunModeUsed != 0x0u) */
            
            /* Set the IRQ to use the status register interrupts */
            RE_Counter1_CONTROL2 |= RE_Counter1_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            RE_Counter1_RT1 &= ~RE_Counter1_RT1_MASK;
            RE_Counter1_RT1 |= RE_Counter1_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            RE_Counter1_RT1 &= ~(RE_Counter1_SYNCDSI_MASK);
            RE_Counter1_RT1 |= RE_Counter1_SYNCDSI_EN;

        #else
            #if(!RE_Counter1_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = RE_Counter1_CONTROL & ~RE_Counter1_CTRL_CMPMODE_MASK;
            RE_Counter1_CONTROL = ctrl | RE_Counter1_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = RE_Counter1_CONTROL & ~RE_Counter1_CTRL_CAPMODE_MASK;
            RE_Counter1_CONTROL = ctrl | RE_Counter1_DEFAULT_CAPTURE_MODE;
            #endif /* (!RE_Counter1_ControlRegRemoved) */
        #endif /* (RE_Counter1_UsingFixedFunction) */
        
        /* Clear all data in the FIFO's */
        #if (!RE_Counter1_UsingFixedFunction)
            RE_Counter1_ClearFIFO();
        #endif /* (!RE_Counter1_UsingFixedFunction) */
        
        /* Set Initial values from Configuration */
        RE_Counter1_WritePeriod(RE_Counter1_INIT_PERIOD_VALUE);
        #if (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A)))
            RE_Counter1_WriteCounter(RE_Counter1_INIT_COUNTER_VALUE);
        #endif /* (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A))) */
        RE_Counter1_SetInterruptMode(RE_Counter1_INIT_INTERRUPTS_MASK);
        
        #if (!RE_Counter1_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            RE_Counter1_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            RE_Counter1_WriteCompare(RE_Counter1_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            RE_Counter1_interruptState = CyEnterCriticalSection();
            
            RE_Counter1_STATUS_AUX_CTRL |= RE_Counter1_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(RE_Counter1_interruptState);
            
        #endif /* (!RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
*******************************************************************************/
void RE_Counter1_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (RE_Counter1_UsingFixedFunction)
        RE_Counter1_GLOBAL_ENABLE |= RE_Counter1_BLOCK_EN_MASK;
        RE_Counter1_GLOBAL_STBY_ENABLE |= RE_Counter1_BLOCK_STBY_EN_MASK;
    #endif /* (RE_Counter1_UsingFixedFunction) */  
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!RE_Counter1_ControlRegRemoved || RE_Counter1_UsingFixedFunction)
        RE_Counter1_CONTROL |= RE_Counter1_CTRL_ENABLE;                
    #endif /* (!RE_Counter1_ControlRegRemoved || RE_Counter1_UsingFixedFunction) */
    
}


/*******************************************************************************
* Function Name: RE_Counter1_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter1_initVar: Is modified when this function is called for the  
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void RE_Counter1_Start(void) 
{
    if(RE_Counter1_initVar == 0u)
    {
        RE_Counter1_Init();
        
        RE_Counter1_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    RE_Counter1_Enable();        
}


/*******************************************************************************
* Function Name: RE_Counter1_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
*******************************************************************************/
void RE_Counter1_Stop(void) 
{
    /* Disable Counter */
    #if(!RE_Counter1_ControlRegRemoved || RE_Counter1_UsingFixedFunction)
        RE_Counter1_CONTROL &= ~RE_Counter1_CTRL_ENABLE;        
    #endif /* (!RE_Counter1_ControlRegRemoved || RE_Counter1_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (RE_Counter1_UsingFixedFunction)
        RE_Counter1_GLOBAL_ENABLE &= ~RE_Counter1_BLOCK_EN_MASK;
        RE_Counter1_GLOBAL_STBY_ENABLE &= ~RE_Counter1_BLOCK_STBY_EN_MASK;
    #endif /* (RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
*******************************************************************************/
void RE_Counter1_SetInterruptMode(uint8 interruptsMask) 
{
    RE_Counter1_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: RE_Counter1_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
*******************************************************************************/
uint8   RE_Counter1_ReadStatusRegister(void) 
{
    return RE_Counter1_STATUS;
}


#if(!RE_Counter1_ControlRegRemoved)
/*******************************************************************************
* Function Name: RE_Counter1_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
uint8   RE_Counter1_ReadControlRegister(void) 
{
    return RE_Counter1_CONTROL;
}


/*******************************************************************************
* Function Name: RE_Counter1_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
void    RE_Counter1_WriteControlRegister(uint8 control) 
{
    RE_Counter1_CONTROL = control;
}

#endif  /* (!RE_Counter1_ControlRegRemoved) */


#if (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A)))
/*******************************************************************************
* Function Name: RE_Counter1_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
*******************************************************************************/
void RE_Counter1_WriteCounter(uint8 counter) \
                                   
{
    #if(RE_Counter1_UsingFixedFunction)
        /* assert if block is already enabled */
        CYASSERT (!(RE_Counter1_GLOBAL_ENABLE & RE_Counter1_BLOCK_EN_MASK));
        /* If block is disabled, enable it and then write the counter */
        RE_Counter1_GLOBAL_ENABLE |= RE_Counter1_BLOCK_EN_MASK;
        CY_SET_REG16(RE_Counter1_COUNTER_LSB_PTR, (uint16)counter);
        RE_Counter1_GLOBAL_ENABLE &= ~RE_Counter1_BLOCK_EN_MASK;
    #else
        CY_SET_REG8(RE_Counter1_COUNTER_LSB_PTR, counter);
    #endif /* (RE_Counter1_UsingFixedFunction) */
}
#endif /* (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A))) */


/*******************************************************************************
* Function Name: RE_Counter1_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) The present value of the counter.
*
*******************************************************************************/
uint8 RE_Counter1_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(RE_Counter1_COUNTER_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG8(RE_Counter1_STATICCOUNT_LSB_PTR));
}


/*******************************************************************************
* Function Name: RE_Counter1_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) Present Capture value.
*
*******************************************************************************/
uint8 RE_Counter1_ReadCapture(void) 
{
   return ( CY_GET_REG8(RE_Counter1_STATICCOUNT_LSB_PTR) );  
}


/*******************************************************************************
* Function Name: RE_Counter1_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint8) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
*******************************************************************************/
void RE_Counter1_WritePeriod(uint8 period) 
{
    #if(RE_Counter1_UsingFixedFunction)
        CY_SET_REG16(RE_Counter1_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG8(RE_Counter1_PERIOD_LSB_PTR,period);
    #endif /* (RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) Present period value.
*
*******************************************************************************/
uint8 RE_Counter1_ReadPeriod(void) 
{
   return ( CY_GET_REG8(RE_Counter1_PERIOD_LSB_PTR));
}


#if (!RE_Counter1_UsingFixedFunction)
/*******************************************************************************
* Function Name: RE_Counter1_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
*******************************************************************************/
void RE_Counter1_WriteCompare(uint8 compare) \
                                   
{
    #if(RE_Counter1_UsingFixedFunction)
        CY_SET_REG16(RE_Counter1_COMPARE_LSB_PTR,(uint16)compare);
    #else
        CY_SET_REG8(RE_Counter1_COMPARE_LSB_PTR,compare);
    #endif /* (RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint8) Present compare value.
*
*******************************************************************************/
uint8 RE_Counter1_ReadCompare(void) 
{
   return ( CY_GET_REG8(RE_Counter1_COMPARE_LSB_PTR));
}


#if (RE_Counter1_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: RE_Counter1_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void RE_Counter1_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    RE_Counter1_CONTROL &= ~RE_Counter1_CTRL_CMPMODE_MASK;
    
    /* Write the new setting */
    RE_Counter1_CONTROL |= (compareMode << RE_Counter1_CTRL_CMPMODE0_SHIFT);
}
#endif  /* (RE_Counter1_COMPARE_MODE_SOFTWARE) */


#if (RE_Counter1_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: RE_Counter1_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void RE_Counter1_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    RE_Counter1_CONTROL &= ~RE_Counter1_CTRL_CAPMODE_MASK;
    
    /* Write the new setting */
    RE_Counter1_CONTROL |= (captureMode << RE_Counter1_CTRL_CAPMODE0_SHIFT);
}
#endif  /* (RE_Counter1_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: RE_Counter1_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
*******************************************************************************/
void RE_Counter1_ClearFIFO(void) 
{

    while(RE_Counter1_ReadStatusRegister() & RE_Counter1_STATUS_FIFONEMP)
    {
        RE_Counter1_ReadCapture();
    }

}
#endif  /* (!RE_Counter1_UsingFixedFunction) */


/* [] END OF FILE */

