/*******************************************************************************
* File Name: RE_Counter1.h  
* Version 2.20
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
    
#if !defined(CY_COUNTER_RE_Counter1_H)
#define CY_COUNTER_RE_Counter1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Counter_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults        
**************************************/

#define RE_Counter1_Resolution            8u
#define RE_Counter1_UsingFixedFunction    0u
#define RE_Counter1_ControlRegRemoved     1u
#define RE_Counter1_COMPARE_MODE_SOFTWARE 0u
#define RE_Counter1_CAPTURE_MODE_SOFTWARE 0u
#define RE_Counter1_RunModeUsed           1u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Mode API Support
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct RE_Counter1_backupStruct
{
    /* Sleep BackUp structure */
    uint8 CounterEnableState; 
    #if (CY_PSOC5A)
        uint8 CounterUdb;    /* Current Counter Value      */
        uint8 CounterPeriod; /* Counter Period Value       */
        uint8 CompareValue;  /* Counter Compare Value      */           
        uint8 InterruptMaskValue; /* Counter Compare Value */
    #endif /* (CY_PSOC5A) */

    #if (CY_PSOC3 || CY_PSOC5LP)
            uint8 CounterUdb;
            uint8 InterruptMaskValue;
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    #if (!RE_Counter1_ControlRegRemoved)
        uint8 CounterControlRegister;          /* Counter Control Register   */
    #endif /* (!RE_Counter1_ControlRegRemoved) */
}RE_Counter1_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    RE_Counter1_Start(void) ;
void    RE_Counter1_Stop(void) ;
void    RE_Counter1_SetInterruptMode(uint8 interruptsMask) ;
uint8   RE_Counter1_ReadStatusRegister(void) ;
#define RE_Counter1_GetInterruptSource() RE_Counter1_ReadStatusRegister()
#if(!RE_Counter1_ControlRegRemoved)
    uint8   RE_Counter1_ReadControlRegister(void) ;
    void    RE_Counter1_WriteControlRegister(uint8 control) \
        ;
#endif /* (!RE_Counter1_ControlRegRemoved) */
#if (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A)))
    void    RE_Counter1_WriteCounter(uint8 counter) \
            ; 
#endif /* (!(RE_Counter1_UsingFixedFunction && (CY_PSOC5A))) */
uint8  RE_Counter1_ReadCounter(void) ;
uint8  RE_Counter1_ReadCapture(void) ;
void    RE_Counter1_WritePeriod(uint8 period) \
    ;
uint8  RE_Counter1_ReadPeriod( void ) ;
#if (!RE_Counter1_UsingFixedFunction)
    void    RE_Counter1_WriteCompare(uint8 compare) \
        ;
    uint8  RE_Counter1_ReadCompare( void ) \
        ;
#endif /* (!RE_Counter1_UsingFixedFunction) */

#if (RE_Counter1_COMPARE_MODE_SOFTWARE)
    void    RE_Counter1_SetCompareMode(uint8 comparemode) ;
#endif /* (RE_Counter1_COMPARE_MODE_SOFTWARE) */
#if (RE_Counter1_CAPTURE_MODE_SOFTWARE)
    void    RE_Counter1_SetCaptureMode(uint8 capturemode) ;
#endif /* (RE_Counter1_CAPTURE_MODE_SOFTWARE) */
void RE_Counter1_ClearFIFO(void)     ;
void RE_Counter1_Init(void)          ;
void RE_Counter1_Enable(void)        ;
void RE_Counter1_SaveConfig(void)    ;
void RE_Counter1_RestoreConfig(void) ;
void RE_Counter1_Sleep(void)         ;
void RE_Counter1_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define RE_Counter1__B_COUNTER__LESS_THAN 1
#define RE_Counter1__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define RE_Counter1__B_COUNTER__EQUAL 0
#define RE_Counter1__B_COUNTER__GREATER_THAN 3
#define RE_Counter1__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define RE_Counter1__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define RE_Counter1_CMP_MODE_LT 1u
#define RE_Counter1_CMP_MODE_LTE 2u
#define RE_Counter1_CMP_MODE_EQ 0u
#define RE_Counter1_CMP_MODE_GT 3u
#define RE_Counter1_CMP_MODE_GTE 4u
#define RE_Counter1_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define RE_Counter1__B_COUNTER__NONE 0
#define RE_Counter1__B_COUNTER__RISING_EDGE 1
#define RE_Counter1__B_COUNTER__FALLING_EDGE 2
#define RE_Counter1__B_COUNTER__EITHER_EDGE 3
#define RE_Counter1__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define RE_Counter1_CAP_MODE_NONE 0u
#define RE_Counter1_CAP_MODE_RISE 1u
#define RE_Counter1_CAP_MODE_FALL 2u
#define RE_Counter1_CAP_MODE_BOTH 3u
#define RE_Counter1_CAP_MODE_SOFTWARE_CONTROLLED 4u


/***************************************
 *  Initialization Values
 **************************************/
#define RE_Counter1_INIT_PERIOD_VALUE       200u
#define RE_Counter1_INIT_COUNTER_VALUE      0u
#if (RE_Counter1_UsingFixedFunction)
#define RE_Counter1_INIT_INTERRUPTS_MASK    ((0u << RE_Counter1_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define RE_Counter1_INIT_COMPARE_VALUE      150u
#define RE_Counter1_INIT_INTERRUPTS_MASK ((0u << RE_Counter1_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        (0u << RE_Counter1_STATUS_CAPTURE_INT_EN_MASK_SHIFT) | \
        (1u << RE_Counter1_STATUS_CMP_INT_EN_MASK_SHIFT) | \
        (0u << RE_Counter1_STATUS_OVERFLOW_INT_EN_MASK_SHIFT) | \
        (0u << RE_Counter1_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT))
#define RE_Counter1_DEFAULT_COMPARE_MODE    (4u << RE_Counter1_CTRL_CMPMODE0_SHIFT)
#define RE_Counter1_DEFAULT_CAPTURE_MODE    (0u << RE_Counter1_CTRL_CAPMODE0_SHIFT)
#endif /* (RE_Counter1_UsingFixedFunction) */


/**************************************
 *  Registers
 *************************************/
#if (RE_Counter1_UsingFixedFunction)
    #define RE_Counter1_STATICCOUNT_LSB     (*(reg16 *) RE_Counter1_CounterHW__CAP0 )
    #define RE_Counter1_STATICCOUNT_LSB_PTR ( (reg16 *) RE_Counter1_CounterHW__CAP0 )
    #define RE_Counter1_PERIOD_LSB          (*(reg16 *) RE_Counter1_CounterHW__PER0 )
    #define RE_Counter1_PERIOD_LSB_PTR      ( (reg16 *) RE_Counter1_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define RE_Counter1_COMPARE_LSB         (*(reg16 *) RE_Counter1_CounterHW__CNT_CMP0 )
    #define RE_Counter1_COMPARE_LSB_PTR     ( (reg16 *) RE_Counter1_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define RE_Counter1_COUNTER_LSB         (*(reg16 *) RE_Counter1_CounterHW__CNT_CMP0 )
    #define RE_Counter1_COUNTER_LSB_PTR     ( (reg16 *) RE_Counter1_CounterHW__CNT_CMP0 )
    #define RE_Counter1_RT1                 (*(reg8 *) RE_Counter1_CounterHW__RT1)
    #define RE_Counter1_RT1_PTR             ( (reg8 *) RE_Counter1_CounterHW__RT1)
#else
    #define RE_Counter1_STATICCOUNT_LSB     (*(reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__F0_REG )
    #define RE_Counter1_STATICCOUNT_LSB_PTR ( (reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__F0_REG )
    #define RE_Counter1_PERIOD_LSB          (*(reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__D0_REG )
    #define RE_Counter1_PERIOD_LSB_PTR      ( (reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__D0_REG )
    #define RE_Counter1_COMPARE_LSB         (*(reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__D1_REG )
    #define RE_Counter1_COMPARE_LSB_PTR     ( (reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__D1_REG )
    #define RE_Counter1_COUNTER_LSB         (*(reg8 *) \
        RE_Counter1_CounterUDB_sC8_counterdp_u0__A0_REG )
    #define RE_Counter1_COUNTER_LSB_PTR     ( (reg8 *)\
        RE_Counter1_CounterUDB_sC8_counterdp_u0__A0_REG )

    #define RE_Counter1_AUX_CONTROLDP0 \
        (*(reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u0__DP_AUX_CTL_REG)
    #define RE_Counter1_AUX_CONTROLDP0_PTR \
        ( (reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u0__DP_AUX_CTL_REG)
    #if (RE_Counter1_Resolution == 16 || RE_Counter1_Resolution == 24 || RE_Counter1_Resolution == 32)
       #define RE_Counter1_AUX_CONTROLDP1 \
           (*(reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u1__DP_AUX_CTL_REG)
       #define RE_Counter1_AUX_CONTROLDP1_PTR \
           ( (reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u1__DP_AUX_CTL_REG)
    #endif /* (RE_Counter1_Resolution == 16 || RE_Counter1_Resolution == 24 || RE_Counter1_Resolution == 32) */
    #if (RE_Counter1_Resolution == 24 || RE_Counter1_Resolution == 32)
       #define RE_Counter1_AUX_CONTROLDP2 \
           (*(reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u2__DP_AUX_CTL_REG)
       #define RE_Counter1_AUX_CONTROLDP2_PTR \
           ( (reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u2__DP_AUX_CTL_REG)
    #endif /* (RE_Counter1_Resolution == 24 || RE_Counter1_Resolution == 32) */
    #if (RE_Counter1_Resolution == 32)
       #define RE_Counter1_AUX_CONTROLDP3 \
           (*(reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u3__DP_AUX_CTL_REG)
       #define RE_Counter1_AUX_CONTROLDP3_PTR \
           ( (reg8 *) RE_Counter1_CounterUDB_sC8_counterdp_u3__DP_AUX_CTL_REG)
    #endif /* (RE_Counter1_Resolution == 32) */
#endif  /* (RE_Counter1_UsingFixedFunction) */

#if (RE_Counter1_UsingFixedFunction)
    #define RE_Counter1_STATUS         (*(reg8 *) RE_Counter1_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define RE_Counter1_STATUS_MASK             (*(reg8 *) RE_Counter1_CounterHW__SR0 )
    #define RE_Counter1_STATUS_MASK_PTR         ( (reg8 *) RE_Counter1_CounterHW__SR0 )
    #define RE_Counter1_CONTROL                 (*(reg8 *) RE_Counter1_CounterHW__CFG0)
    #define RE_Counter1_CONTROL_PTR             ( (reg8 *) RE_Counter1_CounterHW__CFG0)
    #define RE_Counter1_CONTROL2                (*(reg8 *) RE_Counter1_CounterHW__CFG1)
    #define RE_Counter1_CONTROL2_PTR            ( (reg8 *) RE_Counter1_CounterHW__CFG1)
    #if (CY_PSOC3 || CY_PSOC5LP)
        #define RE_Counter1_CONTROL3       (*(reg8 *) RE_Counter1_CounterHW__CFG2)
        #define RE_Counter1_CONTROL3_PTR   ( (reg8 *) RE_Counter1_CounterHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define RE_Counter1_GLOBAL_ENABLE           (*(reg8 *) RE_Counter1_CounterHW__PM_ACT_CFG)
    #define RE_Counter1_GLOBAL_ENABLE_PTR       ( (reg8 *) RE_Counter1_CounterHW__PM_ACT_CFG)
    #define RE_Counter1_GLOBAL_STBY_ENABLE      (*(reg8 *) RE_Counter1_CounterHW__PM_STBY_CFG)
    #define RE_Counter1_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) RE_Counter1_CounterHW__PM_STBY_CFG)
    

    /********************************
    *    Constants
    ********************************/

    /* Fixed Function Block Chosen */
    #define RE_Counter1_BLOCK_EN_MASK          RE_Counter1_CounterHW__PM_ACT_MSK
    #define RE_Counter1_BLOCK_STBY_EN_MASK     RE_Counter1_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define RE_Counter1_CTRL_ENABLE_SHIFT      0x00u
    #define RE_Counter1_ONESHOT_SHIFT          0x02u
    /* Control Register Bit Masks */
    #define RE_Counter1_CTRL_ENABLE            (0x01u << RE_Counter1_CTRL_ENABLE_SHIFT)         
    #define RE_Counter1_ONESHOT                (0x01u << RE_Counter1_ONESHOT_SHIFT)

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        #define RE_Counter1_CTRL_MODE_SHIFT        0x01u    
        #define RE_Counter1_CTRL_MODE_MASK         (0x07u << RE_Counter1_CTRL_MODE_SHIFT)
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Use CFG2 Mode bits to set run mode */
        #define RE_Counter1_CTRL_MODE_SHIFT        0x00u    
        #define RE_Counter1_CTRL_MODE_MASK         (0x03u << RE_Counter1_CTRL_MODE_SHIFT)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    /* Set the mask for interrupt (raw/status register) */
    #define RE_Counter1_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define RE_Counter1_CTRL2_IRQ_SEL          (0x01u << RE_Counter1_CTRL2_IRQ_SEL_SHIFT)     
    
    /* Status Register Bit Locations */
    #define RE_Counter1_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define RE_Counter1_STATUS_ZERO_INT_EN_MASK_SHIFT      (RE_Counter1_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define RE_Counter1_STATUS_ZERO            (0x01u << RE_Counter1_STATUS_ZERO_SHIFT)

    /* Status Register Interrupt Bit Masks*/
    #define RE_Counter1_STATUS_ZERO_INT_EN_MASK       (RE_Counter1_STATUS_ZERO >> 0x04u)
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define RE_Counter1_RT1_SHIFT            0x04u
    #define RE_Counter1_RT1_MASK             (0x03u << RE_Counter1_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define RE_Counter1_SYNC                 (0x03u << RE_Counter1_RT1_SHIFT)
    #define RE_Counter1_SYNCDSI_SHIFT        0x00u
    #define RE_Counter1_SYNCDSI_MASK         (0x0Fu << RE_Counter1_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define RE_Counter1_SYNCDSI_EN           (0x0Fu << RE_Counter1_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    
#else /* !RE_Counter1_UsingFixedFunction */
    #define RE_Counter1_STATUS               (* (reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define RE_Counter1_STATUS_PTR           (  (reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define RE_Counter1_STATUS_MASK          (* (reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define RE_Counter1_STATUS_MASK_PTR      (  (reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define RE_Counter1_STATUS_AUX_CTRL      (*(reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define RE_Counter1_STATUS_AUX_CTRL_PTR  ( (reg8 *) RE_Counter1_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define RE_Counter1_CONTROL              (* (reg8 *) RE_Counter1_CounterUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )
    #define RE_Counter1_CONTROL_PTR          (  (reg8 *) RE_Counter1_CounterUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )


    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define RE_Counter1_CTRL_CMPMODE0_SHIFT    0x00u       /* As defined by Verilog Implementation */
    #define RE_Counter1_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define RE_Counter1_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define RE_Counter1_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define RE_Counter1_CTRL_CMPMODE_MASK      (0x07u << RE_Counter1_CTRL_CMPMODE0_SHIFT)  
    #define RE_Counter1_CTRL_CAPMODE_MASK      (0x03u << RE_Counter1_CTRL_CAPMODE0_SHIFT)  
    #define RE_Counter1_CTRL_RESET             (0x01u << RE_Counter1_CTRL_RESET_SHIFT)  
    #define RE_Counter1_CTRL_ENABLE            (0x01u << RE_Counter1_CTRL_ENABLE_SHIFT) 

    /* Status Register Bit Locations */
    #define RE_Counter1_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define RE_Counter1_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define RE_Counter1_STATUS_CMP_INT_EN_MASK_SHIFT       RE_Counter1_STATUS_CMP_SHIFT       
    #define RE_Counter1_STATUS_ZERO_INT_EN_MASK_SHIFT      RE_Counter1_STATUS_ZERO_SHIFT      
    #define RE_Counter1_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  RE_Counter1_STATUS_OVERFLOW_SHIFT  
    #define RE_Counter1_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT RE_Counter1_STATUS_UNDERFLOW_SHIFT 
    #define RE_Counter1_STATUS_CAPTURE_INT_EN_MASK_SHIFT   RE_Counter1_STATUS_CAPTURE_SHIFT   
    #define RE_Counter1_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  RE_Counter1_STATUS_FIFOFULL_SHIFT  
    #define RE_Counter1_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  RE_Counter1_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define RE_Counter1_STATUS_CMP             (0x01u << RE_Counter1_STATUS_CMP_SHIFT)  
    #define RE_Counter1_STATUS_ZERO            (0x01u << RE_Counter1_STATUS_ZERO_SHIFT) 
    #define RE_Counter1_STATUS_OVERFLOW        (0x01u << RE_Counter1_STATUS_OVERFLOW_SHIFT) 
    #define RE_Counter1_STATUS_UNDERFLOW       (0x01u << RE_Counter1_STATUS_UNDERFLOW_SHIFT) 
    #define RE_Counter1_STATUS_CAPTURE         (0x01u << RE_Counter1_STATUS_CAPTURE_SHIFT) 
    #define RE_Counter1_STATUS_FIFOFULL        (0x01u << RE_Counter1_STATUS_FIFOFULL_SHIFT)
    #define RE_Counter1_STATUS_FIFONEMP        (0x01u << RE_Counter1_STATUS_FIFONEMP_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define RE_Counter1_STATUS_CMP_INT_EN_MASK            RE_Counter1_STATUS_CMP                    
    #define RE_Counter1_STATUS_ZERO_INT_EN_MASK           RE_Counter1_STATUS_ZERO            
    #define RE_Counter1_STATUS_OVERFLOW_INT_EN_MASK       RE_Counter1_STATUS_OVERFLOW        
    #define RE_Counter1_STATUS_UNDERFLOW_INT_EN_MASK      RE_Counter1_STATUS_UNDERFLOW       
    #define RE_Counter1_STATUS_CAPTURE_INT_EN_MASK        RE_Counter1_STATUS_CAPTURE         
    #define RE_Counter1_STATUS_FIFOFULL_INT_EN_MASK       RE_Counter1_STATUS_FIFOFULL        
    #define RE_Counter1_STATUS_FIFONEMP_INT_EN_MASK       RE_Counter1_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define RE_Counter1_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define RE_Counter1_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define RE_Counter1_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define RE_Counter1_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define RE_Counter1_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define RE_Counter1_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* RE_Counter1_UsingFixedFunction */

#endif  /* CY_COUNTER_RE_Counter1_H */


/* [] END OF FILE */

