/*******************************************************************************
* File Name: RE_SynClock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_RE_SynClock_H)
#define CY_CLOCK_RE_SynClock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void RE_SynClock_Start(void) ;
void RE_SynClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void RE_SynClock_StopBlock(void) ;
#endif

void RE_SynClock_StandbyPower(uint8 state) ;
void RE_SynClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 RE_SynClock_GetDividerRegister(void) ;
void RE_SynClock_SetModeRegister(uint8 modeBitMask) ;
void RE_SynClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 RE_SynClock_GetModeRegister(void) ;
void RE_SynClock_SetSourceRegister(uint8 clkSource) ;
uint8 RE_SynClock_GetSourceRegister(void) ;
#if defined(RE_SynClock__CFG3)
void RE_SynClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 RE_SynClock_GetPhaseRegister(void) ;
#endif

#define RE_SynClock_Enable()                       RE_SynClock_Start()
#define RE_SynClock_Disable()                      RE_SynClock_Stop()
#define RE_SynClock_SetDivider(clkDivider)         RE_SynClock_SetDividerRegister(clkDivider, 1)
#define RE_SynClock_SetDividerValue(clkDivider)    RE_SynClock_SetDividerRegister((clkDivider) - 1, 1)
#define RE_SynClock_SetMode(clkMode)               RE_SynClock_SetModeRegister(clkMode)
#define RE_SynClock_SetSource(clkSource)           RE_SynClock_SetSourceRegister(clkSource)
#if defined(RE_SynClock__CFG3)
#define RE_SynClock_SetPhase(clkPhase)             RE_SynClock_SetPhaseRegister(clkPhase)
#define RE_SynClock_SetPhaseValue(clkPhase)        RE_SynClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define RE_SynClock_CLKEN              (* (reg8 *) RE_SynClock__PM_ACT_CFG)
#define RE_SynClock_CLKEN_PTR          ((reg8 *) RE_SynClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define RE_SynClock_CLKSTBY            (* (reg8 *) RE_SynClock__PM_STBY_CFG)
#define RE_SynClock_CLKSTBY_PTR        ((reg8 *) RE_SynClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define RE_SynClock_DIV_LSB            (* (reg8 *) RE_SynClock__CFG0)
#define RE_SynClock_DIV_LSB_PTR        ((reg8 *) RE_SynClock__CFG0)
#define RE_SynClock_DIV_PTR            ((reg16 *) RE_SynClock__CFG0)

/* Clock MSB divider configuration register. */
#define RE_SynClock_DIV_MSB            (* (reg8 *) RE_SynClock__CFG1)
#define RE_SynClock_DIV_MSB_PTR        ((reg8 *) RE_SynClock__CFG1)

/* Mode and source configuration register */
#define RE_SynClock_MOD_SRC            (* (reg8 *) RE_SynClock__CFG2)
#define RE_SynClock_MOD_SRC_PTR        ((reg8 *) RE_SynClock__CFG2)

#if defined(RE_SynClock__CFG3)
/* Analog clock phase configuration register */
#define RE_SynClock_PHASE              (* (reg8 *) RE_SynClock__CFG3)
#define RE_SynClock_PHASE_PTR          ((reg8 *) RE_SynClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define RE_SynClock_CLKEN_MASK         RE_SynClock__PM_ACT_MSK
#define RE_SynClock_CLKSTBY_MASK       RE_SynClock__PM_STBY_MSK

/* CFG2 field masks */
#define RE_SynClock_SRC_SEL_MSK        RE_SynClock__CFG2_SRC_SEL_MASK
#define RE_SynClock_MODE_MASK          (~(RE_SynClock_SRC_SEL_MSK))

#if defined(RE_SynClock__CFG3)
/* CFG3 phase mask */
#define RE_SynClock_PHASE_MASK         RE_SynClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_RE_SynClock_H */


/* [] END OF FILE */
