/*******************************************************************************
* File Name: RF_AMP.c  
* Version 1.90
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RF_AMP.h"

#if (CY_PSOC5A)
    static RF_AMP_BACKUP_STRUCT  RF_AMP_backup;
#endif /* (CY_ PSOC5A) */

/* Constant array for gain settings */
const uint8 RF_AMP_GainArray[9] = { 
    (RF_AMP_RVAL_0K   | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=1  */
    (RF_AMP_RVAL_40K  | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=2  */
    (RF_AMP_RVAL_120K | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=4  */
    (RF_AMP_RVAL_280K | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=8  */
    (RF_AMP_RVAL_600K | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=16 */
    (RF_AMP_RVAL_460K | RF_AMP_R20_40B_40K | RF_AMP_BIAS_LOW), /* G=24, Sets Rin as 20k */
    (RF_AMP_RVAL_620K | RF_AMP_R20_40B_20K | RF_AMP_BIAS_LOW), /* G=32 */
    (RF_AMP_RVAL_470K | RF_AMP_R20_40B_20K | RF_AMP_BIAS_LOW), /* G=48, Sets Rin as 10k */
    (RF_AMP_RVAL_490K | RF_AMP_R20_40B_20K | RF_AMP_BIAS_LOW)  /* G=50, Sets Rin as 10k */
};

/* Constant array for gain compenstion settings */
const uint8 RF_AMP_GainComp[9] = { 
    ( RF_AMP_COMP_4P35PF  | ( RF_AMP_REDC_00 >> 2 )), /* G=1  */
    ( RF_AMP_COMP_4P35PF  | ( RF_AMP_REDC_01 >> 2 )), /* G=2  */
    ( RF_AMP_COMP_3P0PF   | ( RF_AMP_REDC_01 >> 2 )), /* G=4  */
    ( RF_AMP_COMP_3P0PF   | ( RF_AMP_REDC_01 >> 2 )), /* G=8  */
    ( RF_AMP_COMP_3P6PF   | ( RF_AMP_REDC_01 >> 2 )), /* G=16 */
    ( RF_AMP_COMP_3P6PF   | ( RF_AMP_REDC_11 >> 2 )), /* G=24 */
    ( RF_AMP_COMP_3P6PF   | ( RF_AMP_REDC_11 >> 2 )), /* G=32 */
    ( RF_AMP_COMP_3P6PF   | ( RF_AMP_REDC_00 >> 2 )), /* G=48 */
    ( RF_AMP_COMP_3P6PF   | ( RF_AMP_REDC_00 >> 2 ))  /* G=50 */
};

uint8 RF_AMP_initVar = 0u;

#if (CY_PSOC5A)
    uint8 RF_AMP_restoreVal = 0u;
#endif /* CY_PSOC5A */


/*******************************************************************************   
* Function Name: RF_AMP_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  RF_AMP_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_Init(void) 
{
    /* Set PGA mode */
    RF_AMP_CR0_REG = RF_AMP_MODE_PGA;  
    
    /* Set non-inverting PGA mode and reference mode */
    RF_AMP_CR1_REG |= RF_AMP_PGA_NINV;  

    /* Set default gain and ref mode */
    RF_AMP_CR2_REG = RF_AMP_VREF_MODE;

    /* Set gain and compensation */
    RF_AMP_SetGain(RF_AMP_DEFAULT_GAIN);

    /* Set power */
    RF_AMP_SetPower(RF_AMP_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: RF_AMP_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_Enable(void) 
{
    /* If a boost clock is required */
    #if(RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV)
        RF_AMP_BST_REG |= RF_AMP_BST_REG_EN | CyScBoostClk__INDEX;
    #endif /* RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV */
   
    /* PSoC5A */
    #if (CY_PSOC5A)
        /* Enable Pump only if voltage is below threshold */
        if (RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV)
        {
            RF_AMP_SC_MISC_REG |= RF_AMP_PUMP_FORCE;
        }
        
    /* PSoC3, PSoC5LP*/
    #elif (CY_PSOC3 || CY_PSOC5LP)
        /* Enable charge Pump clock for SC block */
        RF_AMP_PUMP_CR1_REG |= RF_AMP_PUMP_CR1_SC_CLKSEL;
        /* Enable Pump only if voltage is below threshold */
        if (RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV)
        {
            RF_AMP_SC_MISC_REG |= RF_AMP_PUMP_FORCE;
        }
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    #if (CY_PSOC5A)
    if(RF_AMP_restoreVal == 1u)
    {
        RF_AMP_CR1_REG = RF_AMP_backup.scCr1Reg;
        RF_AMP_CR2_REG =RF_AMP_backup.scCr2Reg;
        RF_AMP_restoreVal = 0u;
    }
    #endif /* CY_PSOC5A */
     
    /* Enable power to the Amp in Active mode*/
    RF_AMP_PM_ACT_CFG_REG |= RF_AMP_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    RF_AMP_PM_STBY_CFG_REG |= RF_AMP_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: RF_AMP_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(RF_AMP_initVar == 0u)
    {
        RF_AMP_Init();
        RF_AMP_initVar = 1u;
    }

    RF_AMP_Enable();
}


/*******************************************************************************
* Function Name: RF_AMP_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_Stop(void) 
{
    /* Disable pumps only if only one SC block is in use */
    if (RF_AMP_PM_ACT_CFG_REG == RF_AMP_ACT_PWR_EN)
    {
       RF_AMP_SC_MISC_REG &= ~RF_AMP_PUMP_FORCE;
    }   
    /* Disble power to the Amp in Active mode template */
    RF_AMP_PM_ACT_CFG_REG &= ~RF_AMP_ACT_PWR_EN;

    /* Disble power to the Amp in Alternative Active mode template */
    RF_AMP_PM_STBY_CFG_REG &= ~RF_AMP_STBY_PWR_EN;

    /* If a boost clock is required */
    /* Disable SC Block boost clk control, if used (MinVdda < 2.7V) */
    #if(RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV)
        RF_AMP_BST_REG &= ~RF_AMP_BST_REG_EN;
    #endif /* RF_AMP_CYDEV_VDDA_MV < RF_AMP_MINIMUM_VDDA_THRESHOLD_MV */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        RF_AMP_backup.scCr1Reg = RF_AMP_CR1_REG;
        RF_AMP_backup.scCr2Reg = RF_AMP_CR2_REG;
        RF_AMP_CR1_REG = RF_AMP_SC_REG_CLR;
        RF_AMP_CR2_REG = RF_AMP_SC_REG_CLR;
        RF_AMP_restoreVal = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: RF_AMP_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = RF_AMP_CR1_REG & ~RF_AMP_DRIVE_MASK;
    tmpCR |= (power & RF_AMP_DRIVE_MASK);
    RF_AMP_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: RF_AMP_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void RF_AMP_SetGain(uint8 gain) 
{
    /* Only set new gain if it is a valid gain */
    if( gain <= RF_AMP_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        RF_AMP_CR2_REG &= ~(RF_AMP_RVAL_MASK | RF_AMP_R20_40B_MASK | 
                                RF_AMP_REDC_MASK | RF_AMP_BIAS_MASK );

        /* Set gain value resistors, redc comp, and bias */
        RF_AMP_CR2_REG |= (RF_AMP_GainArray[gain] |
                                ( (RF_AMP_GainComp[gain] << 2 ) & RF_AMP_REDC_MASK));

        /* Clear sc_comp  */
        RF_AMP_CR1_REG &= ~RF_AMP_COMP_MASK;
        /* Set sc_comp  */
        RF_AMP_CR1_REG |= ( RF_AMP_GainComp[gain] | RF_AMP_COMP_MASK );
    }
}


/* [] END OF FILE */
