/*******************************************************************************
* File Name: RF_AMP_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power manager source code to the API for PGA 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "RF_AMP.h"

static RF_AMP_BACKUP_STRUCT  RF_AMP_backup;


/*******************************************************************************
* Function Name: RF_AMP_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user register configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: RF_AMP_RestoreConfig
********************************************************************************
*
* Summary:
*  Restore the register configurations.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void RF_AMP_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: RF_AMP_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  RF_AMP_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void RF_AMP_Sleep(void) 
{
    /* Save PGA enable state */
    if(RF_AMP_ACT_PWR_EN == (RF_AMP_PM_ACT_CFG_REG & RF_AMP_ACT_PWR_EN))
    {
        /* Component is enabled */
        RF_AMP_backup.enableState = 1u;
    }
    else
    {
        /* Component is disabled */
        RF_AMP_backup.enableState = 0u;
    }

    /* Stop the configuration */
    RF_AMP_Stop();

    /* Save the configuration */
    RF_AMP_SaveConfig();
}


/*******************************************************************************
* Function Name: RF_AMP_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  void
*
* Global variables:
*  RF_AMP_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
* 
*******************************************************************************/
void RF_AMP_Wakeup(void) 
{
    /* Restore the configurations */
    RF_AMP_RestoreConfig();

     /* Enables the component operation */
    if(RF_AMP_backup.enableState == 1u)
    {
        RF_AMP_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
