/*******************************************************************************
* File Name: ReB.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "ReB.h"

/* APIs are not generated for P15[7:6] */
#if !(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 &&\
     CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_PRODUCTION &&\
	 ReB__PORT == 15 && (ReB__MASK & 0xC0))

/*******************************************************************************
* Function Name: ReB_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void ReB_Write(uint8 value) 
{
    uint8 staticBits = ReB_DR & ~ReB_MASK;
    ReB_DR = staticBits | ((value << ReB_SHIFT) & ReB_MASK);
}


/*******************************************************************************
* Function Name: ReB_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void ReB_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ReB_0, mode);
}


/*******************************************************************************
* Function Name: ReB_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ReB_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ReB_Read(void) 
{
    return (ReB_PS & ReB_MASK) >> ReB_SHIFT;
}


/*******************************************************************************
* Function Name: ReB_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ReB_ReadDataReg(void) 
{
    return (ReB_DR & ReB_MASK) >> ReB_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ReB_INTSTAT) 

    /*******************************************************************************
    * Function Name: ReB_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ReB_ClearInterrupt(void) 
    {
        return (ReB_INTSTAT & ReB_MASK) >> ReB_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
