/*******************************************************************************
* File Name: RotaryEncoder_1_Counter.c  
* Version 2.10
*
*  Description:
*     The Counter User Module consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "RotaryEncoder_1_Counter.h"

uint8 RotaryEncoder_1_Counter_initVar = 0u;


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Init(void) 
{
        #if (!RotaryEncoder_1_Counter_UsingFixedFunction && !RotaryEncoder_1_Counter_ControlRegRemoved)
            uint8 ctrl;
        #endif
        
        #if(!RotaryEncoder_1_Counter_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 RotaryEncoder_1_Counter_interruptState;
        #endif
        
        #if (RotaryEncoder_1_Counter_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            RotaryEncoder_1_Counter_CONTROL &= RotaryEncoder_1_Counter_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (RotaryEncoder_1_Counter_PSOC3_ES2 || RotaryEncoder_1_Counter_PSOC5_ES1)
                RotaryEncoder_1_Counter_CONTROL2 &= ~RotaryEncoder_1_Counter_CTRL_MODE_MASK;
            #endif
            #if (RotaryEncoder_1_Counter_PSOC3_ES3 || RotaryEncoder_1_Counter_PSOC5_ES2)
                RotaryEncoder_1_Counter_CONTROL3 &= ~RotaryEncoder_1_Counter_CTRL_MODE_MASK;                
            #endif
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (RotaryEncoder_1_Counter_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                RotaryEncoder_1_Counter_CONTROL |= RotaryEncoder_1_Counter_ONESHOT;
            #endif
            
            /* Set the IRQ to use the status register interrupts */
            RotaryEncoder_1_Counter_CONTROL2 |= RotaryEncoder_1_Counter_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            RotaryEncoder_1_Counter_RT1 &= ~RotaryEncoder_1_Counter_RT1_MASK;
            RotaryEncoder_1_Counter_RT1 |= RotaryEncoder_1_Counter_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            RotaryEncoder_1_Counter_RT1 &= ~(RotaryEncoder_1_Counter_SYNCDSI_MASK);
            RotaryEncoder_1_Counter_RT1 |= RotaryEncoder_1_Counter_SYNCDSI_EN;

        #else
            #if(!RotaryEncoder_1_Counter_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = RotaryEncoder_1_Counter_CONTROL & ~RotaryEncoder_1_Counter_CTRL_CMPMODE_MASK;
            RotaryEncoder_1_Counter_CONTROL = ctrl | RotaryEncoder_1_Counter_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = RotaryEncoder_1_Counter_CONTROL & ~RotaryEncoder_1_Counter_CTRL_CAPMODE_MASK;
            RotaryEncoder_1_Counter_CONTROL = ctrl | RotaryEncoder_1_Counter_DEFAULT_CAPTURE_MODE;
            #endif
        #endif 
        
        /* Clear all data in the FIFO's */
        #if (!RotaryEncoder_1_Counter_UsingFixedFunction)
            RotaryEncoder_1_Counter_ClearFIFO();
        #endif
        
        /* Set Initial values from Configuration */
        RotaryEncoder_1_Counter_WritePeriod(RotaryEncoder_1_Counter_INIT_PERIOD_VALUE);
        RotaryEncoder_1_Counter_WriteCounter(RotaryEncoder_1_Counter_INIT_COUNTER_VALUE);
        RotaryEncoder_1_Counter_SetInterruptMode(RotaryEncoder_1_Counter_INIT_INTERRUPTS_MASK);
        
        #if (!RotaryEncoder_1_Counter_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            RotaryEncoder_1_Counter_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            RotaryEncoder_1_Counter_WriteCompare(RotaryEncoder_1_Counter_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            RotaryEncoder_1_Counter_interruptState = CyEnterCriticalSection();
            
            RotaryEncoder_1_Counter_STATUS_AUX_CTRL |= RotaryEncoder_1_Counter_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(RotaryEncoder_1_Counter_interruptState);
            
        #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (RotaryEncoder_1_Counter_UsingFixedFunction)
        RotaryEncoder_1_Counter_GLOBAL_ENABLE |= RotaryEncoder_1_Counter_BLOCK_EN_MASK;
        RotaryEncoder_1_Counter_GLOBAL_STBY_ENABLE |= RotaryEncoder_1_Counter_BLOCK_STBY_EN_MASK;
    #endif   
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!RotaryEncoder_1_Counter_ControlRegRemoved || RotaryEncoder_1_Counter_UsingFixedFunction)
        RotaryEncoder_1_Counter_CONTROL |= RotaryEncoder_1_Counter_CTRL_ENABLE;                
    #endif
    
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  RotaryEncoder_1_Counter_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant
*  No
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Start(void) 
{
    if(RotaryEncoder_1_Counter_initVar == 0u)
    {
        RotaryEncoder_1_Counter_Init();
        
        RotaryEncoder_1_Counter_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    RotaryEncoder_1_Counter_Enable();        
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Stop(void) 
{
    /* Disable Counter */
    #if(!RotaryEncoder_1_Counter_ControlRegRemoved || RotaryEncoder_1_Counter_UsingFixedFunction)
        RotaryEncoder_1_Counter_CONTROL &= ~RotaryEncoder_1_Counter_CTRL_ENABLE;        
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (RotaryEncoder_1_Counter_UsingFixedFunction)
        RotaryEncoder_1_Counter_GLOBAL_ENABLE &= ~RotaryEncoder_1_Counter_BLOCK_EN_MASK;
        RotaryEncoder_1_Counter_GLOBAL_STBY_ENABLE &= ~RotaryEncoder_1_Counter_BLOCK_STBY_EN_MASK;
    #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_SetInterruptMode(uint8 interruptsMask) 
{
    RotaryEncoder_1_Counter_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8   RotaryEncoder_1_Counter_ReadStatusRegister(void) 
{
    return RotaryEncoder_1_Counter_STATUS;
}


#if(!RotaryEncoder_1_Counter_ControlRegRemoved)
/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8   RotaryEncoder_1_Counter_ReadControlRegister(void) 
{
    return RotaryEncoder_1_Counter_CONTROL;
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*   
* Reentrant
*  Yes
*
*******************************************************************************/
void    RotaryEncoder_1_Counter_WriteControlRegister(uint8 control) 
{
    RotaryEncoder_1_Counter_CONTROL = control;
}

#endif  /* (!RotaryEncoder_1_Counter_ControlRegRemoved) */


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_WriteCounter(uint8 counter) 
{
    #if(RotaryEncoder_1_Counter_UsingFixedFunction)
        CY_SET_REG16(RotaryEncoder_1_Counter_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG8(RotaryEncoder_1_Counter_COUNTER_LSB_PTR, counter);
    #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) The present value of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8 RotaryEncoder_1_Counter_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(RotaryEncoder_1_Counter_COUNTER_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG8(RotaryEncoder_1_Counter_STATICCOUNT_LSB_PTR));
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) Present Capture value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8 RotaryEncoder_1_Counter_ReadCapture(void) 
{
   return ( CY_GET_REG8(RotaryEncoder_1_Counter_STATICCOUNT_LSB_PTR) );  
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint8) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_WritePeriod(uint8 period) 
{
    #if(RotaryEncoder_1_Counter_UsingFixedFunction)
        CY_SET_REG16(RotaryEncoder_1_Counter_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG8(RotaryEncoder_1_Counter_PERIOD_LSB_PTR,period);
    #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) Present period value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8 RotaryEncoder_1_Counter_ReadPeriod(void) 
{
   return ( CY_GET_REG8(RotaryEncoder_1_Counter_PERIOD_LSB_PTR));
}


#if (!RotaryEncoder_1_Counter_UsingFixedFunction)
/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_WriteCompare(uint8 compare) 
{
    #if(RotaryEncoder_1_Counter_UsingFixedFunction)
        CY_SET_REG16(RotaryEncoder_1_Counter_COMPARE_LSB_PTR,(uint16)compare);
    #else
        CY_SET_REG8(RotaryEncoder_1_Counter_COMPARE_LSB_PTR,compare);
    #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint8) Present compare value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8 RotaryEncoder_1_Counter_ReadCompare(void) 
{
   return ( CY_GET_REG8(RotaryEncoder_1_Counter_COMPARE_LSB_PTR));
}


#if (RotaryEncoder_1_Counter_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    RotaryEncoder_1_Counter_CONTROL &= ~RotaryEncoder_1_Counter_CTRL_CMPMODE_MASK;
    
    /* Write the new setting */
    RotaryEncoder_1_Counter_CONTROL |= (compareMode << RotaryEncoder_1_Counter_CTRL_CMPMODE0_SHIFT);
}
#endif  /* (RotaryEncoder_1_Counter_COMPARE_MODE_SOFTWARE) */


#if (RotaryEncoder_1_Counter_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    RotaryEncoder_1_Counter_CONTROL &= ~RotaryEncoder_1_Counter_CTRL_CAPMODE_MASK;
    
    /* Write the new setting */
    RotaryEncoder_1_Counter_CONTROL |= (captureMode << RotaryEncoder_1_Counter_CTRL_CAPMODE0_SHIFT);
}
#endif  /* (RotaryEncoder_1_Counter_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
* Reentrant
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_ClearFIFO(void) 
{

    while(RotaryEncoder_1_Counter_ReadStatusRegister() & RotaryEncoder_1_Counter_STATUS_FIFONEMP)
    {
        RotaryEncoder_1_Counter_ReadCapture();
    }

}
#endif  /* (!RotaryEncoder_1_Counter_UsingFixedFunction) */


/* [] END OF FILE */

