/*******************************************************************************
* File Name: RotaryEncoder_1_SynClock.h
* Version 1.60
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_RotaryEncoder_1_SynClock_H)
#define CY_CLOCK_RotaryEncoder_1_SynClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void RotaryEncoder_1_SynClock_Start(void) ;
void RotaryEncoder_1_SynClock_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void RotaryEncoder_1_SynClock_StopBlock(void) ;
#endif

void RotaryEncoder_1_SynClock_StandbyPower(uint8 state) ;
void RotaryEncoder_1_SynClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 RotaryEncoder_1_SynClock_GetDividerRegister(void) ;
void RotaryEncoder_1_SynClock_SetModeRegister(uint8 modeBitMask) ;
void RotaryEncoder_1_SynClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 RotaryEncoder_1_SynClock_GetModeRegister(void) ;
void RotaryEncoder_1_SynClock_SetSourceRegister(uint8 clkSource) ;
uint8 RotaryEncoder_1_SynClock_GetSourceRegister(void) ;
#if defined(RotaryEncoder_1_SynClock__CFG3)
void RotaryEncoder_1_SynClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 RotaryEncoder_1_SynClock_GetPhaseRegister(void) ;
#endif

#define RotaryEncoder_1_SynClock_Enable()                       RotaryEncoder_1_SynClock_Start()
#define RotaryEncoder_1_SynClock_Disable()                      RotaryEncoder_1_SynClock_Stop()
#define RotaryEncoder_1_SynClock_SetDivider(clkDivider)         RotaryEncoder_1_SynClock_SetDividerRegister(clkDivider, 1)
#define RotaryEncoder_1_SynClock_SetDividerValue(clkDivider)    RotaryEncoder_1_SynClock_SetDividerRegister((clkDivider) - 1, 1)
#define RotaryEncoder_1_SynClock_SetMode(clkMode)               RotaryEncoder_1_SynClock_SetModeRegister(clkMode)
#define RotaryEncoder_1_SynClock_SetSource(clkSource)           RotaryEncoder_1_SynClock_SetSourceRegister(clkSource)
#if defined(RotaryEncoder_1_SynClock__CFG3)
#define RotaryEncoder_1_SynClock_SetPhase(clkPhase)             RotaryEncoder_1_SynClock_SetPhaseRegister(clkPhase)
#define RotaryEncoder_1_SynClock_SetPhaseValue(clkPhase)        RotaryEncoder_1_SynClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define RotaryEncoder_1_SynClock_CLKEN              (* (reg8 *) RotaryEncoder_1_SynClock__PM_ACT_CFG)
#define RotaryEncoder_1_SynClock_CLKEN_PTR          ((reg8 *) RotaryEncoder_1_SynClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define RotaryEncoder_1_SynClock_CLKSTBY            (* (reg8 *) RotaryEncoder_1_SynClock__PM_STBY_CFG)
#define RotaryEncoder_1_SynClock_CLKSTBY_PTR        ((reg8 *) RotaryEncoder_1_SynClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define RotaryEncoder_1_SynClock_DIV_LSB            (* (reg8 *) RotaryEncoder_1_SynClock__CFG0)
#define RotaryEncoder_1_SynClock_DIV_LSB_PTR        ((reg8 *) RotaryEncoder_1_SynClock__CFG0)
#define RotaryEncoder_1_SynClock_DIV_PTR            ((reg16 *) RotaryEncoder_1_SynClock__CFG0)

/* Clock MSB divider configuration register. */
#define RotaryEncoder_1_SynClock_DIV_MSB            (* (reg8 *) RotaryEncoder_1_SynClock__CFG1)
#define RotaryEncoder_1_SynClock_DIV_MSB_PTR        ((reg8 *) RotaryEncoder_1_SynClock__CFG1)

/* Mode and source configuration register */
#define RotaryEncoder_1_SynClock_MOD_SRC            (* (reg8 *) RotaryEncoder_1_SynClock__CFG2)
#define RotaryEncoder_1_SynClock_MOD_SRC_PTR        ((reg8 *) RotaryEncoder_1_SynClock__CFG2)

#if defined(RotaryEncoder_1_SynClock__CFG3)
/* Analog clock phase configuration register */
#define RotaryEncoder_1_SynClock_PHASE              (* (reg8 *) RotaryEncoder_1_SynClock__CFG3)
#define RotaryEncoder_1_SynClock_PHASE_PTR          ((reg8 *) RotaryEncoder_1_SynClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define RotaryEncoder_1_SynClock_CLKEN_MASK         RotaryEncoder_1_SynClock__PM_ACT_MSK
#define RotaryEncoder_1_SynClock_CLKSTBY_MASK       RotaryEncoder_1_SynClock__PM_STBY_MSK

/* CFG2 field masks */
#define RotaryEncoder_1_SynClock_SRC_SEL_MSK        RotaryEncoder_1_SynClock__CFG2_SRC_SEL_MASK
#define RotaryEncoder_1_SynClock_MODE_MASK          (~(RotaryEncoder_1_SynClock_SRC_SEL_MSK))

#if defined(RotaryEncoder_1_SynClock__CFG3)
/* CFG3 phase mask */
#define RotaryEncoder_1_SynClock_PHASE_MASK         RotaryEncoder_1_SynClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_RotaryEncoder_1_SynClock_H */


/* [] END OF FILE */
