/*******************************************************************************
* File Name: Sig_Trigge.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_Sig_Trigge_H)
#define CY_CLOCK_Sig_Trigge_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void Sig_Trigge_Start(void) ;
void Sig_Trigge_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void Sig_Trigge_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void Sig_Trigge_StandbyPower(uint8 state) ;
void Sig_Trigge_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 Sig_Trigge_GetDividerRegister(void) ;
void Sig_Trigge_SetModeRegister(uint8 modeBitMask) ;
void Sig_Trigge_ClearModeRegister(uint8 modeBitMask) ;
uint8 Sig_Trigge_GetModeRegister(void) ;
void Sig_Trigge_SetSourceRegister(uint8 clkSource) ;
uint8 Sig_Trigge_GetSourceRegister(void) ;
#if defined(Sig_Trigge__CFG3)
void Sig_Trigge_SetPhaseRegister(uint8 clkPhase) ;
uint8 Sig_Trigge_GetPhaseRegister(void) ;
#endif /* defined(Sig_Trigge__CFG3) */

#define Sig_Trigge_Enable()                       Sig_Trigge_Start()
#define Sig_Trigge_Disable()                      Sig_Trigge_Stop()
#define Sig_Trigge_SetDivider(clkDivider)         Sig_Trigge_SetDividerRegister(clkDivider, 1)
#define Sig_Trigge_SetDividerValue(clkDivider)    Sig_Trigge_SetDividerRegister((clkDivider) - 1, 1)
#define Sig_Trigge_SetMode(clkMode)               Sig_Trigge_SetModeRegister(clkMode)
#define Sig_Trigge_SetSource(clkSource)           Sig_Trigge_SetSourceRegister(clkSource)
#if defined(Sig_Trigge__CFG3)
#define Sig_Trigge_SetPhase(clkPhase)             Sig_Trigge_SetPhaseRegister(clkPhase)
#define Sig_Trigge_SetPhaseValue(clkPhase)        Sig_Trigge_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(Sig_Trigge__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Sig_Trigge_CLKEN              (* (reg8 *) Sig_Trigge__PM_ACT_CFG)
#define Sig_Trigge_CLKEN_PTR          ((reg8 *) Sig_Trigge__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Sig_Trigge_CLKSTBY            (* (reg8 *) Sig_Trigge__PM_STBY_CFG)
#define Sig_Trigge_CLKSTBY_PTR        ((reg8 *) Sig_Trigge__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Sig_Trigge_DIV_LSB            (* (reg8 *) Sig_Trigge__CFG0)
#define Sig_Trigge_DIV_LSB_PTR        ((reg8 *) Sig_Trigge__CFG0)
#define Sig_Trigge_DIV_PTR            ((reg16 *) Sig_Trigge__CFG0)

/* Clock MSB divider configuration register. */
#define Sig_Trigge_DIV_MSB            (* (reg8 *) Sig_Trigge__CFG1)
#define Sig_Trigge_DIV_MSB_PTR        ((reg8 *) Sig_Trigge__CFG1)

/* Mode and source configuration register */
#define Sig_Trigge_MOD_SRC            (* (reg8 *) Sig_Trigge__CFG2)
#define Sig_Trigge_MOD_SRC_PTR        ((reg8 *) Sig_Trigge__CFG2)

#if defined(Sig_Trigge__CFG3)
/* Analog clock phase configuration register */
#define Sig_Trigge_PHASE              (* (reg8 *) Sig_Trigge__CFG3)
#define Sig_Trigge_PHASE_PTR          ((reg8 *) Sig_Trigge__CFG3)
#endif /* defined(Sig_Trigge__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Sig_Trigge_CLKEN_MASK         Sig_Trigge__PM_ACT_MSK
#define Sig_Trigge_CLKSTBY_MASK       Sig_Trigge__PM_STBY_MSK

/* CFG2 field masks */
#define Sig_Trigge_SRC_SEL_MSK        Sig_Trigge__CFG2_SRC_SEL_MASK
#define Sig_Trigge_MODE_MASK          (~(Sig_Trigge_SRC_SEL_MSK))

#if defined(Sig_Trigge__CFG3)
/* CFG3 phase mask */
#define Sig_Trigge_PHASE_MASK         Sig_Trigge__CFG3_PHASE_DLY_MASK
#endif /* defined(Sig_Trigge__CFG3) */

#endif /* CY_CLOCK_Sig_Trigge_H */


/* [] END OF FILE */
