/*******************************************************************************
* File Name: TEST.c  
* Version 1.90
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TEST.h"

#if (CY_PSOC5A)
    static TEST_BACKUP_STRUCT  TEST_backup;
#endif /* (CY_ PSOC5A) */

/* Constant array for gain settings */
const uint8 TEST_GainArray[9] = { 
    (TEST_RVAL_0K   | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=1  */
    (TEST_RVAL_40K  | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=2  */
    (TEST_RVAL_120K | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=4  */
    (TEST_RVAL_280K | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=8  */
    (TEST_RVAL_600K | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=16 */
    (TEST_RVAL_460K | TEST_R20_40B_40K | TEST_BIAS_LOW), /* G=24, Sets Rin as 20k */
    (TEST_RVAL_620K | TEST_R20_40B_20K | TEST_BIAS_LOW), /* G=32 */
    (TEST_RVAL_470K | TEST_R20_40B_20K | TEST_BIAS_LOW), /* G=48, Sets Rin as 10k */
    (TEST_RVAL_490K | TEST_R20_40B_20K | TEST_BIAS_LOW)  /* G=50, Sets Rin as 10k */
};

/* Constant array for gain compenstion settings */
const uint8 TEST_GainComp[9] = { 
    ( TEST_COMP_4P35PF  | ( TEST_REDC_00 >> 2 )), /* G=1  */
    ( TEST_COMP_4P35PF  | ( TEST_REDC_01 >> 2 )), /* G=2  */
    ( TEST_COMP_3P0PF   | ( TEST_REDC_01 >> 2 )), /* G=4  */
    ( TEST_COMP_3P0PF   | ( TEST_REDC_01 >> 2 )), /* G=8  */
    ( TEST_COMP_3P6PF   | ( TEST_REDC_01 >> 2 )), /* G=16 */
    ( TEST_COMP_3P6PF   | ( TEST_REDC_11 >> 2 )), /* G=24 */
    ( TEST_COMP_3P6PF   | ( TEST_REDC_11 >> 2 )), /* G=32 */
    ( TEST_COMP_3P6PF   | ( TEST_REDC_00 >> 2 )), /* G=48 */
    ( TEST_COMP_3P6PF   | ( TEST_REDC_00 >> 2 ))  /* G=50 */
};

uint8 TEST_initVar = 0u;

#if (CY_PSOC5A)
    uint8 TEST_restoreVal = 0u;
#endif /* CY_PSOC5A */


/*******************************************************************************   
* Function Name: TEST_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  TEST_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_Init(void) 
{
    /* Set PGA mode */
    TEST_CR0_REG = TEST_MODE_PGA;  
    
    /* Set non-inverting PGA mode and reference mode */
    TEST_CR1_REG |= TEST_PGA_NINV;  

    /* Set default gain and ref mode */
    TEST_CR2_REG = TEST_VREF_MODE;

    /* Set gain and compensation */
    TEST_SetGain(TEST_DEFAULT_GAIN);

    /* Set power */
    TEST_SetPower(TEST_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: TEST_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_Enable(void) 
{
    /* If a boost clock is required */
    #if(TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV)
        TEST_BST_REG |= TEST_BST_REG_EN | CyScBoostClk__INDEX;
    #endif /* TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV */
   
    /* PSoC5A */
    #if (CY_PSOC5A)
        /* Enable Pump only if voltage is below threshold */
        if (TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV)
        {
            TEST_SC_MISC_REG |= TEST_PUMP_FORCE;
        }
        
    /* PSoC3, PSoC5LP*/
    #elif (CY_PSOC3 || CY_PSOC5LP)
        /* Enable charge Pump clock for SC block */
        TEST_PUMP_CR1_REG |= TEST_PUMP_CR1_SC_CLKSEL;
        /* Enable Pump only if voltage is below threshold */
        if (TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV)
        {
            TEST_SC_MISC_REG |= TEST_PUMP_FORCE;
        }
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    #if (CY_PSOC5A)
    if(TEST_restoreVal == 1u)
    {
        TEST_CR1_REG = TEST_backup.scCr1Reg;
        TEST_CR2_REG =TEST_backup.scCr2Reg;
        TEST_restoreVal = 0u;
    }
    #endif /* CY_PSOC5A */
     
    /* Enable power to the Amp in Active mode*/
    TEST_PM_ACT_CFG_REG |= TEST_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    TEST_PM_STBY_CFG_REG |= TEST_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: TEST_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(TEST_initVar == 0u)
    {
        TEST_Init();
        TEST_initVar = 1u;
    }

    TEST_Enable();
}


/*******************************************************************************
* Function Name: TEST_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_Stop(void) 
{
    /* Disable pumps only if only one SC block is in use */
    if (TEST_PM_ACT_CFG_REG == TEST_ACT_PWR_EN)
    {
       TEST_SC_MISC_REG &= ~TEST_PUMP_FORCE;
    }   
    /* Disble power to the Amp in Active mode template */
    TEST_PM_ACT_CFG_REG &= ~TEST_ACT_PWR_EN;

    /* Disble power to the Amp in Alternative Active mode template */
    TEST_PM_STBY_CFG_REG &= ~TEST_STBY_PWR_EN;

    /* If a boost clock is required */
    /* Disable SC Block boost clk control, if used (MinVdda < 2.7V) */
    #if(TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV)
        TEST_BST_REG &= ~TEST_BST_REG_EN;
    #endif /* TEST_CYDEV_VDDA_MV < TEST_MINIMUM_VDDA_THRESHOLD_MV */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        TEST_backup.scCr1Reg = TEST_CR1_REG;
        TEST_backup.scCr2Reg = TEST_CR2_REG;
        TEST_CR1_REG = TEST_SC_REG_CLR;
        TEST_CR2_REG = TEST_SC_REG_CLR;
        TEST_restoreVal = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: TEST_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void TEST_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = TEST_CR1_REG & ~TEST_DRIVE_MASK;
    tmpCR |= (power & TEST_DRIVE_MASK);
    TEST_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: TEST_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void TEST_SetGain(uint8 gain) 
{
    /* Only set new gain if it is a valid gain */
    if( gain <= TEST_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        TEST_CR2_REG &= ~(TEST_RVAL_MASK | TEST_R20_40B_MASK | 
                                TEST_REDC_MASK | TEST_BIAS_MASK );

        /* Set gain value resistors, redc comp, and bias */
        TEST_CR2_REG |= (TEST_GainArray[gain] |
                                ( (TEST_GainComp[gain] << 2 ) & TEST_REDC_MASK));

        /* Clear sc_comp  */
        TEST_CR1_REG &= ~TEST_COMP_MASK;
        /* Set sc_comp  */
        TEST_CR1_REG |= ( TEST_GainComp[gain] | TEST_COMP_MASK );
    }
}


/* [] END OF FILE */
