/*******************************************************************************
* File Name: TEST_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power manager source code to the API for PGA 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "TEST.h"

static TEST_BACKUP_STRUCT  TEST_backup;


/*******************************************************************************
* Function Name: TEST_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user register configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: TEST_RestoreConfig
********************************************************************************
*
* Summary:
*  Restore the register configurations.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void TEST_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: TEST_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  TEST_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void TEST_Sleep(void) 
{
    /* Save PGA enable state */
    if(TEST_ACT_PWR_EN == (TEST_PM_ACT_CFG_REG & TEST_ACT_PWR_EN))
    {
        /* Component is enabled */
        TEST_backup.enableState = 1u;
    }
    else
    {
        /* Component is disabled */
        TEST_backup.enableState = 0u;
    }

    /* Stop the configuration */
    TEST_Stop();

    /* Save the configuration */
    TEST_SaveConfig();
}


/*******************************************************************************
* Function Name: TEST_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  void
*
* Global variables:
*  TEST_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
* 
*******************************************************************************/
void TEST_Wakeup(void) 
{
    /* Restore the configurations */
    TEST_RestoreConfig();

     /* Enables the component operation */
    if(TEST_backup.enableState == 1u)
    {
        TEST_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
