/*******************************************************************************
* File Name: Xclk.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Xclk.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Xclk__PORT == 15 && ((Xclk__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Xclk_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Xclk_Write(uint8 value) 
{
    uint8 staticBits = (Xclk_DR & (uint8)(~Xclk_MASK));
    Xclk_DR = staticBits | ((uint8)(value << Xclk_SHIFT) & Xclk_MASK);
}


/*******************************************************************************
* Function Name: Xclk_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Xclk_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Xclk_0, mode);
}


/*******************************************************************************
* Function Name: Xclk_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Xclk_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Xclk_Read(void) 
{
    return (Xclk_PS & Xclk_MASK) >> Xclk_SHIFT;
}


/*******************************************************************************
* Function Name: Xclk_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Xclk_ReadDataReg(void) 
{
    return (Xclk_DR & Xclk_MASK) >> Xclk_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Xclk_INTSTAT) 

    /*******************************************************************************
    * Function Name: Xclk_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Xclk_ClearInterrupt(void) 
    {
        return (Xclk_INTSTAT & Xclk_MASK) >> Xclk_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
