/*******************************************************************************
* File Name: Xdac_PM.c  
* Version 1.80
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Xdac.h"

static Xdac_backupStruct Xdac_backup;


/*******************************************************************************
* Function Name: Xdac_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Xdac_SaveConfig(void) 
{
    if (!((Xdac_CR1 & Xdac_SRC_MASK) == Xdac_SRC_UDB))
    {
        Xdac_backup.data_value = Xdac_Data;
    }
}


/*******************************************************************************
* Function Name: Xdac_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void Xdac_RestoreConfig(void) 
{
    if (!((Xdac_CR1 & Xdac_SRC_MASK) == Xdac_SRC_UDB))
    {
        if((Xdac_Strobe & Xdac_STRB_MASK) == Xdac_STRB_EN)
        {
            Xdac_Strobe &= ~Xdac_STRB_MASK;
            Xdac_Data = Xdac_backup.data_value;
            Xdac_Strobe |= Xdac_STRB_EN;
        }
        else
        {
            Xdac_Data = Xdac_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Xdac_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Xdac_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void Xdac_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(Xdac_ACT_PWR_EN == (Xdac_PWRMGR & Xdac_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Xdac_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Xdac_backup.enableState = 0u;
    }
    
    Xdac_Stop();
    Xdac_SaveConfig();
}


/*******************************************************************************
* Function Name: Xdac_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Xdac_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Xdac_Wakeup(void) 
{
    Xdac_RestoreConfig();
    
    if(Xdac_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Xdac_Enable();

        /* Restore the data register */
        Xdac_SetValue(Xdac_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
