/*******************************************************************************
* File Name: Ydac_PM.c  
* Version 1.80
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Ydac.h"

static Ydac_backupStruct Ydac_backup;


/*******************************************************************************
* Function Name: Ydac_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Ydac_SaveConfig(void) 
{
    if (!((Ydac_CR1 & Ydac_SRC_MASK) == Ydac_SRC_UDB))
    {
        Ydac_backup.data_value = Ydac_Data;
    }
}


/*******************************************************************************
* Function Name: Ydac_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void Ydac_RestoreConfig(void) 
{
    if (!((Ydac_CR1 & Ydac_SRC_MASK) == Ydac_SRC_UDB))
    {
        if((Ydac_Strobe & Ydac_STRB_MASK) == Ydac_STRB_EN)
        {
            Ydac_Strobe &= ~Ydac_STRB_MASK;
            Ydac_Data = Ydac_backup.data_value;
            Ydac_Strobe |= Ydac_STRB_EN;
        }
        else
        {
            Ydac_Data = Ydac_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Ydac_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Ydac_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void Ydac_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(Ydac_ACT_PWR_EN == (Ydac_PWRMGR & Ydac_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Ydac_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Ydac_backup.enableState = 0u;
    }
    
    Ydac_Stop();
    Ydac_SaveConfig();
}


/*******************************************************************************
* Function Name: Ydac_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Ydac_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Ydac_Wakeup(void) 
{
    Ydac_RestoreConfig();
    
    if(Ydac_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Ydac_Enable();

        /* Restore the data register */
        Ydac_SetValue(Ydac_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
