/*******************************************************************************
* File Name: Yout.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Yout.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Yout__PORT == 15 && ((Yout__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Yout_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Yout_Write(uint8 value) 
{
    uint8 staticBits = (Yout_DR & (uint8)(~Yout_MASK));
    Yout_DR = staticBits | ((uint8)(value << Yout_SHIFT) & Yout_MASK);
}


/*******************************************************************************
* Function Name: Yout_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Yout_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Yout_0, mode);
}


/*******************************************************************************
* Function Name: Yout_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Yout_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Yout_Read(void) 
{
    return (Yout_PS & Yout_MASK) >> Yout_SHIFT;
}


/*******************************************************************************
* Function Name: Yout_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Yout_ReadDataReg(void) 
{
    return (Yout_DR & Yout_MASK) >> Yout_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Yout_INTSTAT) 

    /*******************************************************************************
    * Function Name: Yout_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Yout_ClearInterrupt(void) 
    {
        return (Yout_INTSTAT & Yout_MASK) >> Yout_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
